@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: sv_update_conf.pl,v 1.38 2005/09/21 12:56:23 yeupou Exp $
+# $Id: sv_update_conf.pl 5196 2005-12-02 13:34:58Z yeupou $
 #
 #  Copyright 2002-2005 (c) Mathieu Roy <yeupou--at--gnu.org>
 #                          Sylvain Beucler <beuc--beuc.net>
@@ -33,7 +33,7 @@ use POSIX qw(strftime);
 use File::Basename;
 
 my $getopt;
-my $debug; 
+my $debug;
 my $help;
 my $conffile = "/etc/savannah/savannah.conf";
 my $update;
@@ -69,11 +69,11 @@ eval {
 
 if($help || !$getopt) {
     print STDERR <<EOF;
-Usage: $0 [--conffile=<conffile>] [--help] 
+Usage: $0 [--conffile=<conffile>] [--help]
 
 Generate or update a configuration file for your local
 Savannah installation. This file is called savannah.conf and
-is usually located in /etc/savannah 
+is usually located in /etc/savannah
 With this script, we write savannah.conf.pl, and we use it to
 generate a PHP version.
 
@@ -103,7 +103,7 @@ generate a PHP version.
       --dbname=<name>        Database name
       --dbuser=<user>        Database server user
       --dbpasswd=<passwd>    Database server password
-      --shell=<bin>          Shell provided to users 
+      --shell=<bin>          Shell provided to users
                              (like /usr/bin/sv_membersh)
 
 Author: yeupou\@gnu.org
@@ -119,8 +119,8 @@ if (-e "$conffile.pl") {
     `chmod $mode $conffile.pl`;
     # Actually test to run it
     do "$conffile.pl" or print "\nUnable to run $conffile.pl\n", RED,"Most commonly, it's a privilege issue.",RESET,"\nThe current $conffile.pl will be ignored, and saved\nas $conffile.pl.bak\n\n";
-    print "$conffile.pl exists\n" if $debug; 
-} else { 
+    print "$conffile.pl exists\n" if $debug;
+} else {
     $recreate = 1;
     print "no $conffile.pl - create it\n" if $debug;
 }
@@ -141,9 +141,9 @@ $sys_dbuser= $dbuser if $dbuser;
 $sys_dbpasswd= $dbpasswd if $dbpasswd;
 
 # A function to add easily new questions
-sub AskSetting {    
+sub AskSetting {
     $question_count = $question_count+1;
-    $item = $_[0]; 
+    $item = $_[0];
     $item_name = $_[1];
     $item_help = $_[2];
     $item_example = $_[3];
@@ -157,7 +157,7 @@ sub AskSetting {
     } else {
 	$item_quotes = "\"";
     }
-    
+
     # Get user input if in interactive mode
     if (!$non_interactive) {
 	print "\n$question_count) $item_name\n($item_help)\nEx: ";
@@ -179,7 +179,7 @@ sub AskSetting {
 	# Escape quotes
 	$$item =~ s/$item_quotes/\\$item_quotes/g;
 	# Add the entry
-	$$item = "our \$$item=$item_quotes$$item$item_quotes\;"; 	
+	$$item = "our \$$item=$item_quotes$$item$item_quotes\;";
     }
 }
 
@@ -187,12 +187,12 @@ sub AskSetting {
 ############################################### QUESTIONS #####
 
 if ($recreate) {
-    
+
     unless ($debug) {
 	# We create the conf directory if missing
 	$dirname = dirname($conffile);
 	`mkdir -p $dirname` if ! -e $dirname;
-	
+
         # We make a backup of the configuration file
 	rename("$conffile.pl", "$conffile.pl.bak") && `chmod 0600 $conffile.pl.bak` if -e "$conffile.pl";
 
@@ -207,13 +207,13 @@ if ($recreate) {
     # ask the user to set the correct values.
 
     ## SERVER(S) ##
-   
+
       AskSetting("sys_default_domain", "Default hostname", "It must be the naked form of the domain", "savannah.gnu.org", $sys_default_domain);
 
       AskSetting("sys_https_host", "HTTPS hostname", "It must be the naked form of the domain. If you do not have https server, comment out", "savannah.gnu.org, \$sys_default_domain", $sys_https_host);
       AskSetting("sys_brother_domain", "Brother hostname", "You can run Savane with two different domain names. You will be able to write a different configuration for each one. The two brother/companion sites will share the same database. If you do not have brother/companion site, comment out. If you do not understand what is it about, you probably do not need that feature, comment out.", "savannah.nongnu.org", $sys_brother_domain);
 
-    
+
       AskSetting("sys_dbhost", "SQL database hostname", "--", "localhost", $sys_dbhost);
       AskSetting("sys_dbname", "SQL database name", "--", "savane", $sys_dbname);
       AskSetting("sys_dbuser", "SQL database user", "--", "mysqluser", $sys_dbuser);
@@ -222,7 +222,7 @@ if ($recreate) {
 
 
     ## INSTALLATION PATHS ##
-    
+
       AskSetting("sys_www_topdir", "Path to the PHP frontend top directory (in the source package, it is the directory frontend/php)", "IT MUST BE AN ABSOLUTE PATH NAME", "/usr/src/savane/frontend/php", $sys_www_topdir);
       AskSetting("sys_url_topdir", "Default web directory", "Suffix appended to the default domain", "/", $sys_url_topdir);
       AskSetting("sys_incdir", "Directory contain the site-specific content", "--", "/etc/savannah/savannah-content", $sys_incdir);
@@ -232,10 +232,10 @@ if ($recreate) {
       AskSetting("sys_name", "Platform name", "Name shown on public pages for the whole service", "New Savane Installation", $sys_name, 1);
       AskSetting("sys_unix_group_name", "Server administration project unix name", "Unix group name of the meta-project used for administration. Take care to avoid conflicts with group name existing on your system, take care to select a valid unix group name: no checks will be done for this project unix group name.", "admin", $sys_unix_group_name);
 
-      AskSetting("sys_default_locale", "Default locale", "It must be a valid locale name.", "french", $sys_default_locale);
-      AskSetting("sys_datefmt", "Date format", "Date formatting. If you want to use the default locale formating, comment out (it's usually a good idea)", "Y-M-d H:i", $sys_datefmt);
+      AskSetting("sys_default_locale", "Default locale", "It must be a valid locale name.", "fr_FR", $sys_default_locale);
+      AskSetting("sys_datefmt", "Date format", "Date formatting. Savane normally does a pretty good job at providing a correctly localized date. Unless you really know what you are doing, leave this commented out.", "%Y-%m-%d %H:%M", $sys_datefmt);
 
-      AskSetting("sys_themedefault", "Default theme", "--", "light2", $sys_themedefault);
+      AskSetting("sys_themedefault", "Default theme", "--", "emerald", $sys_themedefault);
       AskSetting("sys_logo_name", "Logo name", "The engine will search for a file like savannah/frontend/php/images/\$theme.theme/\$sys_logo_name. If you do not want any logo, comment out", "floating.png", $sys_logo_name);
 
 
@@ -249,27 +249,27 @@ if ($recreate) {
 
 
     ## USERS ACCOUNTS ##
-    
+
     AskSetting("sys_use_pamauth", "PAM support", "AFS, Kerberos (...) authentication can be made via PAM. If you need users to log in the web interface using PAM, this is what you want. If you do not know what it is about, comment out.", "no", $sys_use_pamauth);
     AskSetting("sys_use_krb5", "Kerberos 5", "If you do not know what it is about, you surely don't have to deal with a kerberos server, say no here.", "no", $sys_use_krb5);
-    
+
     AskSetting("sys_homedir", "[BACKEND SPECIFIC] User home directory", "Usually /home. You can uncomment if you do not plan to provide accounts", "/home", $sys_homedir);
     AskSetting("sys_homedir_subdirs", "[BACKEND SPECIFIC] User home directory subdirs", "Users home is by default /home/user. If you set this to 1, you'll get /home/u/user, and if you set it to 2, you'll get /home/u/us/user. It may be very convenient if you have plenty of users.", "2", $sys_homedir_subdirs);
     AskSetting("sys_shell", "[BACKEND SPECIFIC] User default shell", "sv_membersh is a limited shell, choose /bin/bash if you want to provide full access to your users", "/usr/bin/sv_membersh, /usr/local/bin/sv_membersh", $sys_shell);
-    
-    AskSetting("sys_userx_prefix", "[BACKEND SPECIFIC] Prefix for user* binaries", "If you do not want to use useradd/usermod/userdel that are in the usual PATH but specific ones, you can type here their prefix. Otherwise, comment out", "/usr/local/savannah/bin", $sys_userx_prefix); 
-    
+
+    AskSetting("sys_userx_prefix", "[BACKEND SPECIFIC] Prefix for user* binaries", "If you do not want to use useradd/usermod/userdel that are in the usual PATH but specific ones, you can type here their prefix. Otherwise, comment out", "/usr/local/savannah/bin", $sys_userx_prefix);
+
     ## CRONJOBS ##
-    
+
     AskSetting("sys_cron_users", "[BACKEND SPECIFIC] Cron job: related to users", "If you do not want your system to be synchronized with database automatically regarding to users infos (/home/$user, /etc/passwd)), comment out", "yes", $sys_cron_users);
     AskSetting("sys_cron_groups", "[BACKEND SPECIFIC] Cron job: related to groups/projects", "If you do not want your system to be synchronized with database automatically regarding to groups infos (/etc/group), comment out", "yes", $sys_cron_groups);
-  
-    AskSetting("sys_cron_viewcvs_forbidden", "[BACKEND SPECIFIC] Cron job: related to viewcvs ignore list", "If you do not want your system to be synchronized with database automatically regarding to viewcvs forbidden list, comment out", "yes", $sys_cron_viewcvs_forbidden);  
-  
-    AskSetting("sys_cron_mail", "[BACKEND SPECIFIC] Cron job: related to mails", "If you do not want your system to be synchronized with database automatically regarding to mail infos (/etc/aliases...), comment out", "yes", $sys_cron_mail);  
-    AskSetting("sys_cron_mailman", "[BACKEND SPECIFIC] Cron job: related to mailman", "If you do not want your system to be synchronized with database automatically regarding to mailman list (it assume you have mailman installed on this system), comment out", "yes", $sys_cron_mailman); 
+
+    AskSetting("sys_cron_viewcvs_forbidden", "[BACKEND SPECIFIC] Cron job: related to viewcvs ignore list", "If you do not want your system to be synchronized with database automatically regarding to viewcvs forbidden list, comment out", "yes", $sys_cron_viewcvs_forbidden);
+
+    AskSetting("sys_cron_mail", "[BACKEND SPECIFIC] Cron job: related to mails", "If you do not want your system to be synchronized with database automatically regarding to mail infos (/etc/aliases...), comment out", "yes", $sys_cron_mail);
+    AskSetting("sys_cron_mailman", "[BACKEND SPECIFIC] Cron job: related to mailman", "If you do not want your system to be synchronized with database automatically regarding to mailman list (it assume you have mailman installed on this system), comment out", "yes", $sys_cron_mailman);
     AskSetting("sys_cron_cleaner", "[BACKEND SPECIFIC] Cron job: database cleaning", "A special backend script will clean regularly the database. If you do not want that cleaning to be done, comment out. It is recommended to use it, even if your installation use no other backend tool", "yes", $sys_cron_cleaner);
-    AskSetting("sys_cron_reminder", "[BACKEND SPECIFIC] Cron job: trackers reminder", "A special backend script will check regularly the database and send email to users in defined cases. An user can decide to receive regularly task assigned to him in a batch ; a project administrator can decide to make people that got item with high priority not closed receiving a batch. Also, when an item is supposed to start of to finish, a reminder should be sent to anybody supposed to get notification for the item", "yes", $sys_cron_reminder);  
+    AskSetting("sys_cron_reminder", "[BACKEND SPECIFIC] Cron job: trackers reminder", "A special backend script will check regularly the database and send email to users in defined cases. An user can decide to receive regularly task assigned to him in a batch ; a project administrator can decide to make people that got item with high priority not closed receiving a batch. Also, when an item is supposed to start of to finish, a reminder should be sent to anybody supposed to get notification for the item", "yes", $sys_cron_reminder);
 
 
     ## EXTRA FEATURES ##
@@ -300,7 +300,7 @@ if ($recreate) {
 #
 # Savane Site Configuration:
 #
-# \$Id: sv_update_conf.pl,v 1.38 2005/09/21 12:56:23 yeupou Exp $
+# \$Id: sv_update_conf.pl 5196 2005-12-02 13:34:58Z yeupou $
 #
 # This file has been generated by sv_update_conf
 # If you modify it, run sv_update_conf --update
@@ -318,7 +318,7 @@ if ($recreate) {
 #      - these files are executed
 #  While it offers the incredible advantage to avoid reinventing a boring
 #  config parser and to permit hackers to create very efficient config
-#  by using perl/php, if anybody can edit it, anybody can push savannah to 
+#  by using perl/php, if anybody can edit it, anybody can push savannah to
 #  execute malicious code when looking for it's configuration.
 #  (But it's like a /etc/profile ... /etc is for admins).
 #
@@ -348,13 +348,13 @@ use warnings;
       # Ex: "savannah.gnu.org"
         # OPTIONAL (comment out if not appliable)
         $sys_https_host
-      
+
       # Brother HTTP(s) domain:
-      # You can run Savannah with two different domain names. You'll be able 
+      # You can run Savannah with two different domain names. You'll be able
       # to write a different configuration for each one.
       # The two brother/companion sites will share the same database.
       # Here you can let your savannah installation aware of the existence
-      # of a brother/companion site, so while people login, it will be allowed 
+      # of a brother/companion site, so while people login, it will be allowed
       # to them to login on both site in one click.
       # If you do not have brother/companion site, comment out.
         # OPTIONAL (comment out if not appliable)
@@ -367,7 +367,7 @@ use warnings;
         $sys_dbhost
         # REQUIRED
         $sys_dbname
-        # REQUIRED	
+        # REQUIRED
         $sys_dbuser
         # REQUIRED
         $sys_dbpasswd
@@ -382,12 +382,12 @@ use warnings;
       # Ex: "/usr/src/savane/frontend/php"
         # REQUIRED
         $sys_www_topdir
-      
-      # Default web directory - suffix appended to the default domain 
+
+      # Default web directory - suffix appended to the default domain
       # Ex: "/", "/savane"
         # REQUIRED
         $sys_url_topdir
-    
+
       # Local dir of the site-specific content
       # Ex: "/etc/savannah/savannah-content"
         # REQUIRED
@@ -395,39 +395,42 @@ use warnings;
 
 
     ## GUI ##
-      
+
       # Platform name, server administration project:
-      # Name of the platform running and unix_group_name of the project 
+      # Name of the platform running and unix_group_name of the project
       # dedicated of the server administration
-      # Ex: "New Savane Installation", "admin", 
+      # Ex: "New Savane Installation", "admin",
         # REQUIRED
         $sys_name
         # REQUIRED
         $sys_unix_group_name
-      
+
       # Default locale and date formatting.
-      # Ex: "fr_FR", "Y-M-d H:i"
+      # Ex: "fr_FR", "%Y-%m-%d %H:%M"
         # OPTIONAL (comment out if not appliable)
         $sys_default_locale
-      # If you want to use the default locale formating, comment out
+      # Savane normally does a pretty good job at providing a correctly 
+      # localized date. This option allows you to force a specific date
+      # format.  Unless you really know what you are doing, leave this
+      # commented out
         # OPTIONAL (comment out if not appliable)
         $sys_datefmt
 
       # Frontend look:
       # Default theme, logo filename
-      # The engine will search for a file like 
+      # The engine will search for a file like
       #    frontend/php/images/\$theme.theme/$sys_logo_name
-      # Ex: "light2", "floating.png"
+      # Ex: "emerald", "floating.png"
         # REQUIRED
         $sys_themedefault
         # OPTIONAL (comment out if not appliable)
-        $sys_logo_name      
+        $sys_logo_name
 
     ## MAIL, MAILING-LIST ##
 
       # Mail domain, admin mail address, default replyto when
       # no reply is possible, email addresses list, email aliases
-      # Ex: "gnu.org", "help", "NO-REPLY.INVALID-ADDRESS", 
+      # Ex: "gnu.org", "help", "NO-REPLY.INVALID-ADDRESS",
       # "/etc/email-addresses," "/etc/aliases"
         # REQUIRED
         $sys_mail_domain
@@ -440,15 +443,15 @@ use warnings;
         # OPTIONAL (comment out if not appliable)
         $sys_mail_aliases
 
-    
+
     ## USERS ACCOUNTS ##
-      
+
       # Provide web interface login through PAM
       # (it can be AFS, Kerberos...)
       # Ex: "yes", "no"
         # OPTIONAL (comment out if not appliable)
         $sys_use_pamauth
-      
+
       # Kerberos:
       # If you do not know what it is about, you surely don't have to
       # deal with a kerberos server, say no here.
@@ -460,7 +463,7 @@ use warnings;
       # [BACKEND ONLY]
       # user* binaries path
       # If you do not want to use useradd/usermod/userdel that are in the
-      # usual PATH but specific ones, you can type here their prefix. 
+      # usual PATH but specific ones, you can type here their prefix.
       # Otherwise, comment out.
       # If you do not know that this setting is about, comment out.
         # OPTIONAL (comment out if not appliable)
@@ -488,7 +491,7 @@ use warnings;
 
 
     ## CRONJOBS ##
-    
+
       # [BACKEND ONLY]
       # Cron jobs
       # If you do not want system to be synchronized with database
@@ -509,19 +512,19 @@ use warnings;
         # OPTIONAL (comment out if not appliable)
         $sys_cron_viewcvs_forbidden
 
-    
+
     ## EXTRA FEATURES ##
-      
+
       # [BACKEND ONLY]
       # viewcvs ignore list
       # If you do not use viewcvs, if you do not want the backend to
       # edit that list comment out
         # OPTIONAL (comment out if not appliable)
-        $sys_viewcvs_conffile 
+        $sys_viewcvs_conffile
 
       # search via google added to the search module
         # OPTIONAL (comment out if not appliable)
-        $sys_use_google 
+        $sys_use_google
 
       # local admin doc: path of this path will be made available to site
       # admins
@@ -534,11 +537,11 @@ use warnings;
       # test machine
       #our \$sys_debug_on=\"1\"\;
 
-    
+
     ## WORKAROUNDS ##
 
       # DEPRECATED:
-      # settings from the original code that does not seems usable nor 
+      # settings from the original code that does not seems usable nor
       # usefull. They are needed in order for the PHP frontend to run for now.
       #our \$sys_urlroot=\"\$sys_www_topdir\"\;
       our \$sys_replyto=\"\$sys_mail_replyto\"\;
@@ -551,12 +554,12 @@ use warnings;
 EOF
 
     unless ($debug) {
-	
+
 	# close the conffile, set it properly
 	close(CONFFILE);
 	`chmod $mode $conffile.pl`;
 	print CYAN, "\n\t** $conffile.pl (re)created **\n\n", RESET;
-	    
+
 	}
 }
 
@@ -582,7 +585,7 @@ print CONFFILEPHP "// DO NOT MODIFY THIS FILE
 //      - these files are executed
 // While it offers the incredible advantage to avoid reinventing a boring
 // config parser and to permit hackers to create very efficient config
-// by using perl/php, if anybody can edit it, anybody can push savannah to 
+// by using perl/php, if anybody can edit it, anybody can push savannah to
 // execute malicious code when looking for it's configuration.
 // (But it's like a /etc/profile ... /etc is for admins).
 //
@@ -600,16 +603,16 @@ while (<CONFFILEPL>) {
     next if /^\s*(#|$)/;
 		  print CONFFILEPHP "$_";
 }
-    
+
 print CONFFILEPHP "// NOTHING SHOULD REMAIN BEYOND THE PHP CLOSING TAG\n";
 print CONFFILEPHP "?>";
-   
+
 close(CONFFILEPHP);
 close(CONFFILEPL);
 
 `chmod $mode $conffile.php`;
-`chown root.$http_user $conffile.php $conffile.pl` if $http_user; 
-    
+`chown root.$http_user $conffile.php $conffile.pl` if $http_user;
+
 print "\nYou asked this script to run in non-interactive mode. You should \nprobably edit the file $conffile.pl now\n" if $non_interactive;
 
 
