@@ -2,7 +2,7 @@
 // This file is part of the Savane project
 // <http://gna.org/projects/savane/>
 //
-// $Id: index.php,v 1.14 2005/06/30 17:19:34 toddy Exp $
+// $Id: index.php 5187 2005-12-01 16:22:29Z yeupou $
 //
 //
 // 
@@ -43,7 +43,8 @@ $is_admin_page='y';
 // if ($group_id && (user_ismember($group_id, 'F2'))) {
 if ($group_id && (user_ismember($group_id, 'A'))) {
 
-	site_project_header(array('group'=>$group_id,'toptab'=>'aforum'));
+	site_project_header(array('group'=>$group_id,'context'=>'aforum'));
+
 	if ($post_changes) {
 		/*
 			Update the DB to reflect the changes
@@ -416,7 +417,8 @@ if ($group_id && (user_ismember($group_id, 'A'))) {
 			Show main page for choosing 
 			either moderotor or delete
 		*/
-		//site_project_header(array('group'=>$group_id,'toptab'=>'aforum'));
+		//site_project_header(array('group'=>$group_id,'context'=>'aforum'));
+
 			  
 		echo '
 			<H2>Forum Administration</H2>
