@@ -2,7 +2,7 @@
 // This file is part of the Savane project
 // <http://gna.org/projects/savane/>
 //
-// $Id: forum.php,v 1.23 2005/08/18 18:07:53 beuc Exp $
+// $Id: forum.php 5187 2005-12-01 16:22:29Z yeupou $
 //
 //
 // Copyright 1999-2000 (c) The SourceForge Crew
@@ -118,7 +118,8 @@ if ($forum_id)
   // in case it is news
   // otherwise it pretends this item does not exist.
   // marcus marker
-  forum_header(array('group'=>$group_id,'toptab'=>'forum','title'=>$forum_name));
+  forum_header(array('group'=>$group_id,'context'=>'forum','title'=>$forum_name));
+
 	
   //private forum check
   if (db_result($result,0,'is_public') != '1') 
@@ -128,7 +129,7 @@ if ($forum_id)
 	  /*
 				If this is a private forum, kick 'em out
 	  */
-	  echo '<h1>Forum is restricted</H1>';
+	  print '<h1>Forum is restricted</H1>';
 	  forum_footer(array());
 	  exit;
 	}
@@ -191,7 +192,7 @@ if ($forum_id)
   
        if ($group_id==$GLOBALS['sys_group_id']) 
 	{ // NEWS ADMIN
-	  echo '<INPUT TYPE="HIDDEN" NAME="forum_id" VALUE="'.$forum_id.'">';
+	  print '<INPUT TYPE="HIDDEN" NAME="forum_id" VALUE="'.$forum_id.'">';
 	} 
       else
 	{
@@ -358,11 +359,11 @@ if ($forum_id)
       $ret_val .= '</TABLE>';
     }
 	
-  echo $ret_val;
+  print $ret_val;
 	
-  echo '<P>&nbsp;<P>';
+  print '<p>&nbsp;</p>';
 	
-  echo '<CENTER><h3>Start a New Thread:</H3></CENTER>';
+  print '<h3>'.html_anchor(_("Start a New Thread:"), "newthread").'</h3>';
   show_post_form($forum_id);
 	
   forum_footer(array());	
@@ -370,7 +371,7 @@ if ($forum_id)
 else
 {
   forum_header(array('title'=>'Error'));
-  echo '<H1>Error - choose a forum first</H1>';
+  print '<H1>Error - choose a forum first</H1>';
   forum_footer(array());	
 }
 
