@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: account.php,v 1.25 2005/09/05 13:26:58 toddy Exp $
+# $Id: account.php 5187 2005-12-01 16:22:29Z yeupou $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2000-2003 (c) Free Software Foundation
@@ -27,7 +27,6 @@
 
 function account_pwvalid ($pw) 
 {
-  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':account_pwvalid ($pw) ';
   $MIN_PASSWD_LENGTH=3;
   if (strlen($pw) < $MIN_PASSWD_LENGTH)
     {
@@ -41,7 +40,6 @@ function account_pwvalid ($pw)
 
 function account_namevalid ($name, $allow_dashes=0, $allow_underscores=1)
 {
-  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':account_namevalid ($name)';
   # By default, underscore are allowed, creating no specific issue for an
   # account name. It may creates trouble if the account is use to handle DNS...
   if ($allow_underscores) {
@@ -113,7 +111,6 @@ function account_namevalid ($name, $allow_dashes=0, $allow_underscores=1)
 
 function account_groupnamevalid ($name)
 {
-  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':account_groupnamevalid ';
   
   # Test with the usual namevalid function, allowing dashes
   if (!account_namevalid($name, 1, 0)) 
@@ -213,7 +210,7 @@ function account_groupnamevalid ($name)
 # The following is a random salt generator
 function account_gensalt()
 {
-	$GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':account_gensalt()';  function rannum(){	     
+  function rannum(){	     
     mt_srand((double)microtime()*1000000);		  
     $num = mt_rand(46,122);		  
     return $num;		  
@@ -236,14 +233,12 @@ function account_gensalt()
 # generate unix pw
 function account_genunixpw($plainpw)
 {
-	$GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':account_genunixpw($plainpw)';
   return crypt($plainpw,account_gensalt());
 }
 
 # returns next userid
 function account_nextuid()
 {
-	$GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':account_nextuid()';
   db_query("SELECT max(unix_uid) AS maxid FROM user");
   $row = db_fetch_array();
   return ($row[maxid] + 1);
@@ -252,7 +247,6 @@ function account_nextuid()
 # print out shell selects
 function account_shellselects($current)
 {
-	$GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':account_shellselects($current)';
   $shells = file("/etc/shells");
 
   for ($i = 0; $i < count($shells); $i++)
