@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: calendar.php,v 1.6 2005/06/30 17:19:35 toddy Exp $
+# $Id: calendar.php 5187 2005-12-01 16:22:29Z yeupou $
 #
 # Took from Annif <http://gna.org/projects/annif/>
 # Copyright 2003 (c) Mathieu Roy <yeupou--at--gnu.org>
@@ -52,6 +52,29 @@ function calendar_month_name ($month)
     } 
 }
 
+function calendar_day_name ($day)
+{
+  # Start monday, not sunday...
+  switch ($day) 
+    {
+    case '1': 
+      return _("Monday"); break;
+    case '2': 
+      return _("Tuesday"); break;
+    case '3': 
+      return _("Wednesday"); break;
+    case '4': 
+      return _("Thursday"); break;
+    case '5': 
+      return _("Friday"); break;
+    case '6': 
+      return _("Saturday"); break;
+    case '7': 
+      return _("Sunday"); break;
+    } 
+}
+
+
 function calendar_days_count ($month)
 {
   if ($month == '2')
