@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: features_boxes.php,v 1.50 2005/08/31 21:05:09 yeupou Exp $
+# $Id: features_boxes.php 5187 2005-12-01 16:22:29Z yeupou $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2000-2003 (c) Free Software Foundation
@@ -27,7 +27,6 @@
 
 function show_features_boxes()
 {
-	$GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':show_features_boxes() ';
   GLOBAL $HTML;
 
   #### General Stats
@@ -98,7 +97,6 @@ function show_features_boxes()
 
 function show_sitestats()
 {
-  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':show_sitestats() ';
   $return .= '<font class="smaller">';
   $users = stats_getusers();
   $return .= sprintf(ngettext("%s registered user", "%s registered users", $users), "<b>$users</b>");
@@ -125,7 +123,6 @@ function show_sitestats()
 
 function show_newest_projects($group_type, $limit)
 {
-  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':show_newest_projects($group_type) ';
   global $j;
 
   $sql =	"SELECT group_id,unix_group_name,group_name,register_time FROM groups " .
@@ -154,7 +151,7 @@ function show_newest_projects($group_type, $limit)
 	      # implementations cant do that, apparently. Feel free to
 	      # improve.
 	      $return .= '<div class="'.utils_get_alt_row_color($j).'"><font class="smaller">&nbsp;&nbsp;- <a href="'.$base_url.$GLOBALS['sys_home']."projects/$row_newproj[unix_group_name]/\">"
-		 . $row_newproj[group_name].'</a><font class="smaller">, '.strftime('%x',$row_newproj['register_time']).'</font></font></div>';
+		 . $row_newproj[group_name].'</a><font class="smaller">, '.format_date('minimal',$row_newproj['register_time']).'</font></font></div>';
 	      $j++;
 	    }
 	}
