@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: html.php,v 1.69 2005/09/28 08:12:18 yeupou Exp $
+# $Id: html.php 5187 2005-12-01 16:22:29Z yeupou $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2000-2003 (c) Free Software Foundation
@@ -85,12 +85,11 @@ function html_splitpage ($how)
 
 function html_nextprev ($search_url, $rows, $rows_returned)
 {
-  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':html_nextprev ($search_url, $rows, $rows_returned) ';
   global $offset, $max_rows;
 
   if (($rows_returned > $rows) || ($offset != 0))
     {
-      print "\n<br /><h5 align=\"center\">\n";
+      print "\n<br /><h5 class=\"nextprev\">\n";
 
       if ($offset != 0)
 	{
@@ -125,50 +124,54 @@ function html_anchor ($content, $name)
   return '<a name="'.$name.'" href="#'.$name.'">'.$content.'</a>';
 }
 
+##
+# Print out the feedback
 function html_feedback_top()
 {
-  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':html_feedback_top() ';
+  # By default, escape the html special chars, unless feedback_html was 
+  # set in the code to allow an htmlized feedback (that should happen on rare
+  # occasions)
+  if (!$GLOBALS[feedback_html])
+    {
+      $GLOBALS[feedback] = htmlspecialchars($GLOBALS[feedback]);
+      $GLOBALS[ffeedback] = htmlspecialchars($GLOBALS[ffeedback]);
+    }
 
   # Only success
   if ($GLOBALS[feedback] && !$GLOBALS[ffeedback])
-    {  print '<h3 class="feedback"><span class="feedbacktitle"><img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/ok.png" class="feedbackimage" alt="'._("Success").'" /> '._("Success:").'</span> '.htmlspecialchars($GLOBALS[feedback]).'</h3>'; }
+    {  print '<div class="feedback"><span class="feedbacktitle"><img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/ok.png" class="feedbackimage" alt="'._("Success").'" /> '._("Success:").'</span> '.$GLOBALS[feedback].'</div>'; }
 
   # Only errors
   if ($GLOBALS[ffeedback] && !$GLOBALS[feedback])
-    {  print '<h3 class="feedbackerror"><span class="feedbackerrortitle"><img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/wrong.png" class="feedbackimage" alt="'._("Error").'" /> '._("Error:").'</span>'.htmlspecialchars($GLOBALS[ffeedback]).'</h3>'; }
+    {  print '<div class="feedbackerror"><span class="feedbackerrortitle"><img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/wrong.png" class="feedbackimage" alt="'._("Error").'" /> '._("Error:").'</span>'.$GLOBALS[ffeedback].'</div>'; }
 
   # Errors and success
   if ($GLOBALS[ffeedback] && $GLOBALS[feedback])
-    {  print '<h3 class="feedbackerrorandsuccess"><span class="feedbackerrorandsuccesstitle"><img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/wrong.png" class="feedbackimage" alt="'._("Some Errors").'" /> '._("Some Errors:").'</span>'.htmlspecialchars($GLOBALS[feedback]).' '.htmlspecialchars($GLOBALS[ffeedback]).'</h3>'; }
+    {  print '<div class="feedbackerrorandsuccess"><span class="feedbackerrorandsuccesstitle"><img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/wrong.png" class="feedbackimage" alt="'._("Some Errors").'" /> '._("Some Errors:").'</span>'.$GLOBALS[feedback].' '.$GLOBALS[ffeedback].'</div>'; }
 
   if ($GLOBALS[sys_debug_on] && $GLOBALS[debug])
-    {  print '<h3 class="debug">DEBUG information: '.$GLOBALS[debug].'</h3>'; }
+    {  print '<div class="debug">DEBUG information: '.$GLOBALS[debug].'</div>'; }
+
   # yeupou@gnu.org 2003-11-03:
   # We unset feedback so there will be a bottom feedback only if something
   # changed. It may confuse users, however I would find more confusing to
   # have to lookalike feedback information providing most of the time the
-  # same information AND (that's the problem) sometimes more information
+  # same information AND (that is the problem) sometimes more information
   # in the second one.
   unset($GLOBALS[feedback],$GLOBALS[ffeedback],$GLOBALS[debug]);
 }
 
+##
+# Do as the feeback on the top of the page
 function html_feedback_bottom()
 {
-  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':html_feedback_bottom() ';
-
- if ($GLOBALS[feedback])
-    {  print '<h3 class="feedback">'.htmlspecialchars($GLOBALS[feedback]).'</h3>'; }
-  if ($GLOBALS[ffeedback])
-    {  print '<h3 class="feedbackerror">'.htmlspecialchars($GLOBALS[ffeedback]).'</h3>'; }
-  if ($GLOBALS[sys_debug_on] && $GLOBALS[debug])
-    {  print '<h3 class="debug">DEBUG information: '.htmlspecialchars($GLOBALS[debug]).'</h3>'; }
+  html_feedback_top();
 }
 
 
 
 function html_image ($src,$args,$display=1)
 {
-  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':html_image($src,$args,$display=1) ';
   GLOBAL $img_attr;
   $return = ('<img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/'.$src.'"');
   reset($args);
@@ -217,7 +220,6 @@ function html_image ($src,$args,$display=1)
 
 function html_build_list_table_top ($title_arr,$links_arr=false,$table=true)
 {
-  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':html_build_list_table_top ';
   /*
 		Takes an array of titles and builds
 		The first row of a new table
@@ -257,7 +259,6 @@ function html_build_list_table_top ($title_arr,$links_arr=false,$table=true)
 
 function html_get_alt_row_color ($i)
 {
-  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':html_get_alt_row_color ($i) ';
   GLOBAL $HTML;
   if ($i % 2 == 0)
     {
@@ -272,7 +273,6 @@ function html_get_alt_row_color ($i)
 #deprecated
 function utils_get_alt_row_color ($i)
 {
-  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':utils_get_alt_row_color ($i) ';
   return html_get_alt_row_color ($i);
 }
 
@@ -280,7 +280,6 @@ function utils_get_alt_row_color ($i)
 
 function html_build_select_box_from_array ($vals,$select_name,$checked_val='xzxz',$samevals = 0)
 {
-  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':html_build_select_box_from_array ';
   /*
 		Takes one array, with the first array being the "id" or value
 		and the array being the text you want displayed
@@ -297,7 +296,7 @@ function html_build_select_box_from_array ($vals,$select_name,$checked_val='xzxz
 
   for ($i=0; $i<$rows; $i++)
     {
-      if ( $samevals )
+      if ($samevals)
 	{
 	  $return .= "\n\t\t<option value=\"" . $vals[$i] . "\"";
 	  if ($vals[$i] == $checked_val)
@@ -331,7 +330,6 @@ function html_build_select_box_from_arrays ($vals,
 					    $text_any='Any', #8
 					    $show_unknown=false)
 {
-  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':html_build_select_box_from_arrays ';
   /*
 
   The infamous '100 row' has to do with the
@@ -423,7 +421,6 @@ function html_build_select_box_from_arrays ($vals,
 
 function html_build_select_box ($result, $name, $checked_val="xzxz",$show_100=true,$text_100='None',$show_any=false,$text_any='Any',$show_unknown=false)
 {
-  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':html_build_select_box  ';
   /*
 		Takes a result set, with the first column being the "id" or value
 		and the second column being the text you want displayed
@@ -442,7 +439,6 @@ function html_build_select_box ($result, $name, $checked_val="xzxz",$show_100=tr
 
 function html_build_multiple_select_box ($result,$name,$checked_array,$size='8',$show_100=true,$text_100='None', $show_any=false,$text_any='Any',$show_value=true)
 {
-  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':html_build_multiple_select_box ';
   /*
 		Takes a result set, with the first column being the "id" or value
 		and the second column being the text you want displayed
@@ -527,7 +523,6 @@ function html_build_multiple_select_box ($result,$name,$checked_array,$size='8',
 
 function html_select_permission_box ($artifact, $row, $level="member")
 {
-  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':html_select_permission_box ($artifact, $row, $level="member")';
   # If $row['user_id'] does not exists, we havent got a row but simple value
   # and it means that we are about to modify per group default
   if ($level == "type")
@@ -666,7 +661,6 @@ function html_select_restriction_box ($artifact, $row, $level="group", $notd=0,
 # method -> perl module -> sub name
 function html_select_typedir_box ($input_name, $current_value)
 {
-  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':html_select_typedir_box ';
   print '<br />&nbsp;&nbsp;
       <select name="'.$input_name.'">
         <option value="basicdirectory"'.(($current_value == "basicdirectory")?" selected":"").'>'._("Basic Directory").'</option>
@@ -729,7 +723,6 @@ function html_select_theme_box ($input_name="user_theme", $current=0)
 
 function html_build_priority_select_box ($name='priority', $checked_val='5')
 {
-  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':html_build_priority_select_box ';
   /*
 		Return a select box of standard priorities.
 		The name of this select box is optional and so is the default checked value
@@ -760,69 +753,71 @@ function html_build_priority_select_box ($name='priority', $checked_val='5')
 																																    }
 function html_buildpriority_select_box ($name='priority', $checked_val='5')
 {
-  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':html_buildpriority_select_box  ';
   return html_build_priority_select_box($name, $checked_val);
 }
 
 
 function html_build_checkboxarray($options,$name,$checked_array)
 {
-  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':html_build_checkboxarray ';
   $option_count=count($options);
   $checked_count=count($checked_array);
 
   for ($i=1; $i<=$option_count; $i++)
     {
       print '
-			<BR><INPUT type="checkbox" name="'.$name.'" value="'.$i.'"';
+			<br><input type="checkbox" name="'.$name.'" value="'.$i.'"';
       for ($j=0; $j<$checked_count; $j++)
 	{
 	  if ($i == $checked_array[$j])
 	    {
-	      print ' CHECKED';
+	      print ' checked="checked"';
 	    }
 	}
-      print '> '.$options[$i];
+      print ' /> '.$options[$i];
     }
 }
 
 function html_buildcheckboxarray($options,$name,$checked_array)
 {
-  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':html_buildcheckboxarray ';
   #deprecated
   return html_build_checkboxarray($options,$name,$checked_array);
 }
 
 function html_build_checkbox ($name, $is_checked=0)
 {
-  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':html_build_checkbox ($name, $is_checked=0)';
   print  '<input type="checkbox" name="'.$name.'" value="1"';
   if ($is_checked)
-    { print ' checked'; }
-  print '>';
+    { print ' checked="checked"'; }
+  print ' />';
 }
 
-/*!     @function site_user_header
-        @abstract everything required to handle security and
-                add navigation for user pages like /my/ and /account/
-        @param params array() must contain $user_id
-        @result text - prints HTML to the screen directly
-*/
-function site_header($params)
+##
+# Catch all header functions
+function html_header($params)
 {
-  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':site_header($params) ';
   global $HTML;
   print $HTML->header($params);
   print html_feedback_top($GLOBALS['feedback']);
-  print $HTML->site_tabs($params);
+  print $HTML->tabs($params);
+}
+
+function html_footer($params)
+{
+  global $HTML;
+  print html_feedback_bottom($GLOBALS['feedback']);
+  $HTML->footer($params);
+}
+
+##
+# aliases of catch all header functions
+function site_header($params)
+{
+  html_header($params);
 }
 
 function site_footer($params)
 {
-  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':site_footer($params) ';
-  global $HTML;
-  print html_feedback_bottom($GLOBALS['feedback']);
-  $HTML->footer($params);
+  html_footer($params);
 }
 
 /*
@@ -833,21 +828,12 @@ function site_footer($params)
 
 /*! 	@function site_project_header
 	@abstract everything required to handle security and state checks for a project web page
-	@param params array() must contain $toptab and $group
+	@param params array() must contain $context and $group
 	@result text - prints HTML to the screen directly
 */
 function site_project_header($params)
 {
-  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':site_project_header($params) ';
-  global $HTML;
-
-  /*
-		Check to see if active
-		Check to see if project rather than foundry
-		Check to see if private (if private check if user_ismember)
-  */
-
-  $group_id=$params['group'];
+  global $group_id;
 
   #get the project object
   $project=project_get_object($group_id);
@@ -872,9 +858,7 @@ function site_project_header($params)
       session_require(array('group'=>$GLOBALS['sys_group_id']));
     }
 
-  print $HTML->header($params);
-  print html_feedback_top($GLOBALS['feedback']);
-  print $HTML->project_tabs($params);
+  html_header($params);
 }
 
 /*!     @function site_project_footer
@@ -885,10 +869,7 @@ function site_project_header($params)
 */
 function site_project_footer($params)
 {
-  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':site_project_footer($params) ';
-  global $HTML;
-  print html_feedback_bottom($GLOBALS['feedback']);
-  print $HTML->footer($params);
+  html_footer($params);
 }
 
 /*
@@ -904,19 +885,8 @@ function site_project_footer($params)
 */
 function site_user_header($params)
 {
-  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':site_user_header($params) ';
-  global $HTML;
-
-  /*
-		Check to see if active user
-		Check to see if logged in
-  */
-
   session_require(array('isloggedin'=>'1'));
-
-  print $HTML->header($params);
-  print html_feedback_top($GLOBALS['feedback']);
-  print $HTML->user_tabs($params);
+  html_header($params);
 }
 
 /*!     @function site_user_footer
@@ -927,10 +897,7 @@ function site_user_header($params)
 */
 function site_user_footer($params)
 {
-  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':site_user_footer($params) ';
-  global $HTML;
-  html_feedback_bottom($GLOBALS['feedback']);
-  print $HTML->footer($params);
+  html_footer($params);
 }
 
 /*
@@ -940,27 +907,17 @@ function site_user_footer($params)
 
 function site_admin_header($params)
 {
-  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':site_admin_header($params) ';
-  global $HTML,$feedback;
-
   session_require(array('group'=>'1','admin_flags'=>'A'));
-
-  $HTML->header($params);
-  print html_feedback_top($feedback);
-  $HTML->admin_tabs($params);
+  html_header($params);
 }
 
 function site_admin_footer($params)
 {
-  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':site_admin_footer($params) ';
-  global $HTML,$feedback;
-  html_feedback_bottom($feedback);
-  $HTML->footer($params);
+  html_footer($params);
 }
 
 function show_group_type_box($name='group_type',$checked_val='xzxz', $show_select_one=false)
 {
-  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':show_group_type_box ';
   $result=db_query("SELECT * FROM group_type");
   return html_build_select_box($result,'group_type',$checked_val,$show_select_one, "> "._("Choose one below"));
 }
@@ -968,7 +925,6 @@ function show_group_type_box($name='group_type',$checked_val='xzxz', $show_selec
 
 function html_member_explain_roles ()
 {
-  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':html_member_explain_roles ';
 
   print _("Technicians, and only technicians, can be assigned tracker's items. They cannot reassign items, change the status or priority of items.");
   print '<p>';
