@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: member.php,v 1.7 2005/06/30 17:19:35 toddy Exp $
+# $Id: member.php 5187 2005-12-01 16:22:29Z yeupou $
 #
 #  Copyright 2003-2005 (c) Mathieu Roy <yeupou--at--gnu.org>
 # 
@@ -20,13 +20,10 @@
 # along with the Savane project; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 
-
-
 # Add or update a user to/in a group
 # status is the 'admin_flags', can be pending or admin
 function member_add ($user_id, $group_id, $status='') 
 {
-  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':member_add ';  
   
   if(!member_check($user_id,$group_id) || user_is_super_user())
     {
@@ -58,7 +55,6 @@ function member_add ($user_id, $group_id, $status='')
 # Approve a pending user for a group
 function member_approve ($user_id, $group_id)
 {
-  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':member_approve ($user_id, $group_id)';
   $sql = "UPDATE user_group SET admin_flags='' WHERE user_id='$user_id' AND group_id='$group_id'";
   $result = db_query($sql);
   if ($result) 
@@ -68,7 +64,6 @@ function member_approve ($user_id, $group_id)
 
 function member_remove ($user_id, $group_id) 
 {
-  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':member_remove ($user_id, $group_id) ';
   $sql = "DELETE FROM user_group WHERE user_id='$user_id' AND group_id='$group_id'";
   $result = db_query($sql);
   if ($result) 
@@ -80,7 +75,6 @@ function member_remove ($user_id, $group_id)
 # Get all permissions for a given user
 function member_getpermissions ($group_id, $flags, $user_id=0) 
 {
-  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':member_getpermissions ($group_id, $flags, $user_id=0) ';
   if (!$user_id)
     {
       $user_id = user_getid();
@@ -109,7 +103,6 @@ function member_getpermissions ($group_id, $flags, $user_id=0)
 # you can use that flag.
 function member_check ($user_id=0, $group_id, $flag=0, $strict=0)
 {
-  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':member_check ';
   # get the current user_id if missing
   if (!$user_id)
     {
@@ -169,6 +162,7 @@ function member_check ($user_id=0, $group_id, $flag=0, $strict=0)
 	case 'T': { $flag_tracker = "task"; break; }
 	case 'S': { $flag_tracker = "support"; break; }
 	case 'N': { $flag_tracker = "news"; break; }
+	case 'C': { $flag_tracker = "cookbook"; break; }
 	}
   
       # get the value 
@@ -278,7 +272,6 @@ function member_check_private ($user_id=0, $group_id)
 #  it could be directly inside member_check)
 function member_create_tracker_flag ($artifact)
 {
-  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':member_create_tracker_flag ($artifact)'; 
   switch ($artifact)
     {
     case 'bugs': { return "B"; }
@@ -286,6 +279,7 @@ function member_create_tracker_flag ($artifact)
     case 'task': { return "T"; }
     case 'support': { return "S"; }
     case 'news': { return "N"; }
+    case 'cookbook': { return "C"; }
     }
 }
 
@@ -293,7 +287,6 @@ function member_create_tracker_flag ($artifact)
 # Return value: The whole row of user_group
 function member_check_is_pending ($user_id, $group_id)
 {
-  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':member_check_is_pending ($user_id, $group_id)';
   return member_check($user_id, $group_id, 'P');
 }
 
