@@ -2,12 +2,12 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: forum.php,v 1.9 2005/06/30 17:19:35 toddy Exp $
+# $Id: forum.php 5187 2005-12-01 16:22:29Z yeupou $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2000-2003 (c) Free Software Foundation
 #
-#  Copyright 2004      (c) Mathieu Roy <yeupou--gnu.org>.
+#  Copyright 2004-2005 (c) Mathieu Roy <yeupou--gnu.org>.
 #
 # The Savane project is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -25,7 +25,6 @@
 
 function forum_show_a_nested_message ($result,$row=0)
 {
-	$GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':forum_show_a_nested_message ($result,$row=0) ';
 	/*
 
 	accepts a database result handle to display a single message
@@ -68,7 +67,6 @@ function forum_show_a_nested_message ($result,$row=0)
 }
 
 function forum_show_nested_messages ($thread_id, $msg_id) {
-	$GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':forum_show_nested_messages ';
 	global $total_rows,$sys_datefmt;
 
 	$sql="SELECT user.user_name,forum.has_followups,user.realname,user.user_id,forum.msg_id,forum.group_forum_id,forum.subject,forum.thread_id,forum.body,forum.date,forum.is_followup_to, forum_group_list.group_id  ".
@@ -115,7 +113,6 @@ function forum_show_nested_messages ($thread_id, $msg_id) {
 # FIXME: site_project_header function should be used instead
 function forum_header($params)
 {
-	$GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':forum_header($params)';
 	global $DOCUMENT_ROOT,$HTML,$group_id,$forum_name,$thread_id,$msg_id,$forum_id,$REQUEST_URI,$sys_datefmt,$et,$et_cookie;
 
 	$params['group']=$group_id;
@@ -137,7 +134,8 @@ function forum_header($params)
                     #print '<font class="error">'._("Error").' - '._("This news item was not found").'</font>';
                     #print "forum_name=$forum_name<br />";
                     site_project_header($params);
-                    #site_project_header(array('group'=>$group_id,'toptab'=>'forum'));
+                    #site_project_header(array('group'=>$group_id,'context'=>'forum'));
+
                 }
             else
                 {
@@ -163,9 +161,10 @@ function forum_header($params)
 <div class="indexcenter">
 ';
 
-
-                    print '<h3>'._("Item posted by").' '.utils_user_link(user_getname(db_result($result,0,'submitted_by')), user_getrealname(db_result($result,0,'submitted_by')));
-                    print ' '._("on").' '. format_date($sys_datefmt,db_result($result,0,'date')).'</h3>';
+		    print '<h3>'.html_anchor(db_result($result,0,'summary'), "content").'</h3>';
+                    print '<p class="italic">'.sprintf(_("Item posted by %s on %s."), 
+						       utils_user_link(user_getname(db_result($result,0,'submitted_by')), user_getrealname(db_result($result,0,'submitted_by'))),
+						       format_date($sys_datefmt,db_result($result,0,'date'))).'</p>';
                     print '<p>';
                     print  utils_make_links(nl2br( db_result($result,0,'details')), $group_id);
 
@@ -184,7 +183,7 @@ function forum_header($params)
 	*/
 	if ($forum_id && $forum_name && $is_news)
         {
-            print '<h3 class="clearr">'._("Comments").'</h3>';
+            print '<h3 class="clearr">'.html_anchor(_("Comments:"), "comments").'</h3>';
         }
 	print '<P><B>';
 
@@ -208,18 +207,16 @@ function forum_header($params)
         print ' | <A HREF="'.$GLOBALS['sys_home'].'forum/admin/?group_id='.$group_id.'">Admin</A></B>';
       }
 	*/
-	print '<P>';
+	print '</P>';
 }
 
 # Backward compatibility
 function forum_footer($params){
-	$GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':forum_footer($params)';
 	site_project_footer($params);
 }
 
 function forum_create_forum($group_id,$forum_name,$is_public=1,$create_default_message=1,$description='')
 {
-	$GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':forum_create_forum ';
 	global $feedback;
 	/*
 		Adding forums to this group
@@ -251,13 +248,11 @@ function forum_create_forum($group_id,$forum_name,$is_public=1,$create_default_m
 
 function make_links ($data="")
 {
-	$GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':make_links ($data="")';
 	#moved make links to /include/utils.php
 	utils_make_links($data);
 }
 
 function get_forum_name($id){
-	$GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':get_forum_name($id)';
 	/*
 		Takes an ID and returns the corresponding forum name
 	*/
@@ -276,7 +271,6 @@ function get_forum_name($id){
 
 function show_thread($thread_id,$et=0)
 {
-	$GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':show_thread($thread_id,$et=0)';
 	/*
 		Takes a thread_id and fetches it, then invokes show_submessages to nest the threads
 
@@ -353,7 +347,6 @@ function show_thread($thread_id,$et=0)
 
 function show_submessages($thread_id, $msg_id, $level,$et=0)
 {
-	$GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':show_submessages($thread_id, $msg_id, $level,$et=0)';
 	/*
 		Recursive. Selects this message's id in this thread,
 		then checks if any messages are nested underneath it.
@@ -433,7 +426,6 @@ function show_submessages($thread_id, $msg_id, $level,$et=0)
 
 function get_next_thread_id()
 {
-	$GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':get_next_thread_id()';
 	/*
 		Get around limitation in MySQL - Must use a separate table with an auto-increment
 	*/
@@ -453,7 +445,6 @@ function get_next_thread_id()
 
 function get_forum_saved_date($forum_id)
 {
-	$GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':get_forum_saved_date($forum_id)';
 	/*
 		return the save_date for this user
 	*/
@@ -484,7 +475,6 @@ function get_forum_saved_date($forum_id)
 
 function post_message($thread_id, $is_followup_to, $subject, $body, $group_forum_id)
 {
-	$GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':post_message($thread_id, $is_followup_to, $subject, $body, $group_forum_id)';
 	global $feedback;
 	if (user_isloggedin())
         {
@@ -580,7 +570,6 @@ function post_message($thread_id, $is_followup_to, $subject, $body, $group_forum
 
 function show_post_form($forum_id, $thread_id=0, $is_followup_to=0, $subject="")
 {
-	$GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':show_post_form($forum_id, $thread_id=0, $is_followup_to=0, $subject="")';
 
 	if (user_isloggedin())
         {
@@ -627,7 +616,6 @@ function show_post_form($forum_id, $thread_id=0, $is_followup_to=0, $subject="")
 
 function handle_monitoring($forum_id,$msg_id)
 {
-	$GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':handle_monitoring($forum_id,$msg_id) ';
 	global $feedback;
 	/*
 		Checks to see if anyone is monitoring this forum
@@ -761,7 +749,6 @@ function handle_monitoring($forum_id,$msg_id)
 
 function recursive_delete($msg_id,$forum_id)
 {
-	$GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':recursive_delete($msg_id,$forum_id)';
 	/*
 		Take a message id and recurse, deleting all followups
 	*/
