@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: general.php,v 1.23 2005/06/30 17:19:35 toddy Exp $
+# $Id: general.php 5187 2005-12-01 16:22:29Z yeupou $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2000-2003 (c) Free Software Foundation
@@ -30,7 +30,6 @@ function news_new_subbox($row)
 
 function news_show_latest ($group_id,$limit=10,$show_summaries="true",$start_from="no")
 {
-  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':news_show_latest ($group_id,$limit=10,$show_summaries="true",$start_from="no") ';
   global $sys_datefmt;
   /*
 		Show a simple list of the latest news items with a link to the forum
@@ -155,7 +154,6 @@ function news_show_latest ($group_id,$limit=10,$show_summaries="true",$start_fro
 
 function news_total_number($group_id)
 {
-	$GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':news_total_number($group_id) ';
   # We want the total number of news for a group
   if ($group_id != $GLOBALS['sys_group_id'])
     {
@@ -175,7 +173,6 @@ function news_total_number($group_id)
 
 function get_news_name($id)
 {
-	$GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':get_news_name($id) ';
   /*
 		Takes an ID and returns the corresponding forum name
   */
