@@ -2,13 +2,13 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: project_home.php,v 1.123 2005/09/27 13:15:24 yeupou Exp $
+# $Id: project_home.php 5187 2005-12-01 16:22:29Z yeupou $
 #
 # Copyright 1999-2000 (c) The SourceForge Crew
 # Copyright 2000-2003 (c) Free Software Foundation
 #
-# Copyright 2002-2005 (c) Mathieu Roy <yeupou--at--gnu.org>
-#                         Yves Perrin <yves.perrin--at--cern.ch>
+# Copyright 2002-2005 (c) Mathieu Roy <yeupou--gnu.org>
+#                         Yves Perrin <yves.perrin--cern.ch>
 #
 # The Savane project is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -29,6 +29,7 @@ require_directory("news");
 require_directory("stats");
 require $GLOBALS['sys_www_topdir']."/include/vars.php";
 
+
 # if we are at wrong url, redirect
 if ($HTTP_HOST != $project->getTypeBaseHost() && $project->getTypeBaseHost())
 {
@@ -37,9 +38,8 @@ if ($HTTP_HOST != $project->getTypeBaseHost() && $project->getTypeBaseHost())
 }
 
 $group_name = $project->getUnixName();
-site_project_header(array('group'=>$group_id,
-			  'toptab'=>'home'));
 
+site_project_header(array());
 
 # ########################### Members of this project
 # (little box on the right)
@@ -98,19 +98,13 @@ print $HTML->box_bottom();
 print '<br />
 ';
 
-if ($project->Uses("bugs") || 
-    $project->Uses("task") || 
-    $project->Uses("support") ||
-    $project->Uses("patch"))
-{
-  
-  print $HTML->box_top(_("Search in this Group"));
-  print '<font class="smaller">';
-  print search_box('','');
-  print '</font>';
-  print $HTML->box_bottom();
-}
 
+# As all projects use the cookbook, this is accurate is all cases
+print $HTML->box_top(_("Search in this Group"));
+print '<font class="smaller">';
+print search_box('','');
+print '</font>';
+print $HTML->box_bottom();
 
 print '
 </div><!-- end indexright -->
@@ -245,8 +239,8 @@ function specific_makesep ()
 print $HTML->box_top(_("Public Areas: Quick Overview"));
 $i = 1;
 $j = $i;
-# Homepage Link
 
+# Homepage Link
 if ($project->Uses("homepage"))
 {
   print utils_link($project->getUrl("homepage"),
@@ -254,13 +248,22 @@ if ($project->Uses("homepage"))
   $i++;
 }
 
+# Cookbook Documentation (internal)
+# Projects dont have the choice to use it, as there maybe site recipe that
+# applies to features they use.
+# FIXME: this should print the number of recipes available
+specific_makesep();
+print utils_link($project->getArtifactUrl("cookbook"),
+		 html_image("man.png",array('width'=>'24', 'height'=>'24', 'alt'=>_("Cookbook"))).'&nbsp;'._("Cookbook"));
+$i++;
+
 # Documentation (extra link)
 if ($project->Uses("extralink_documentation"))
 {
   specific_makesep();
 
   print utils_link($project->getUrl("extralink_documentation"),
-		   html_image("man.png",array('width'=>'24', 'height'=>'24', 'alt'=>_("Documentation"))).'&nbsp;'._("Documentation"));
+		   html_image("man.png",array('width'=>'24', 'height'=>'24', 'alt'=>_("Other Documentation"))).'&nbsp;'._("Other Documentation"));
   $i++;
 }
 
@@ -284,13 +287,13 @@ printf(ngettext("%s member", "%s members", $membersnum[count]), "<b>$membersnum[
 print ")";
 $i++;
 
-if ($project->getGPGKeyring()) 
+if ($project->getGPGKeyring())
 {
   specific_makesep();
   print utils_link($GLOBALS['sys_home'].'project/memberlist-gpgkeys.php?group='.$group_name,
 		   html_image("keys.png",array('width'=>'24', 'height'=>'24', 'alt'=>'GPG Keyring')).'&nbsp;'._("Project Members GPG Keyring"));
   $i++;
-  
+
 }
 
 
@@ -311,13 +314,6 @@ if ($GLOBALS[sys_unix_group_name] == $group_name ||
   $i = 1;
   $j = $i;
 
-  if ($GLOBALS[sys_unix_group_name] == $group_name) {
-    print utils_link($GLOBALS['sys_home'].'faq/?group='.$group_name,
-		     html_image("man.png",array('width'=>'24', 'height'=>'24', 'alt'=>_("Frequently Asked Questions"))).'&nbsp;'._("Frequently Asked Questions"));
-    $i++;
-  }
-
-
   # Support Manager
 
   if ($project->Uses("support")) {
