@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: sendmail.php,v 1.24 2005/09/19 09:34:13 yeupou Exp $
+# $Id: sendmail.php 5187 2005-12-01 16:22:29Z yeupou $
 #
 #  Copyright 2003-2005 (c) Mathieu Roy <yeupou--gnu.org>
 # 
@@ -39,7 +39,6 @@ function sendmail_mail ($from,
 			$exclude_list=0) 
 {
 
-  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':sendmail_mail  ';
 
   # Make sure that users cannot insert malicious content
   # (apart in message, which is not part of the headers)
@@ -270,7 +269,7 @@ function sendmail_encode_header_content ($header, $charset="UTF-8")
 # A form for logged in users to send mails to others users
 function sendmail_form_message ($form_action, $user_id) 
 {
-	$GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':sendmail_form_message ($form_action, $user_id) ';  global $HTML;
+  global $HTML;
   $HTML->box1_top(sprintf(_("Send a Message to %s"),user_getrealname($user_id)));
   print '<p class="warn">'.("If you are writing for help, did you read the project 
 documentation first? Try to provide any potentially useful information you can think of.").'</p>';
