@@ -2,13 +2,13 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: session.php,v 1.27 2005/06/30 17:19:35 toddy Exp $
+# $Id: session.php 5187 2005-12-01 16:22:29Z yeupou $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2000-2003 (c) Free Software Foundation
 #
-#  Copyright 2003-2004 (c) Mathieu Roy <yeupou--at--gnu.org>
-#                          Derek Feichtinger <derek.feichtinger@cern.ch>
+#  Copyright 2003-2005 (c) Mathieu Roy <yeupou--at--gnu.org>
+#                          Derek Feichtinger <derek.feichtinger--cern.ch>
 # 
 # The Savane project is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -35,7 +35,6 @@ function session_login_valid($form_loginname,
 			     $crypted_pw=0,
 			     $stay_in_ssl=1)
 {
-  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':session_login_valid($form_loginname,';			    
 
   # Password is crypted if we are coming from the brother site.
   # Normally, users should use this feature
@@ -56,9 +55,8 @@ function session_login_valid($form_loginname,
       fb(_('Invalid User Name'), 1);
       return false;
     }
-  $usr = db_fetch_array($res);
-
 
+  $usr = db_fetch_array($resq);
 
   # TODO: Brother site login mechanism should be implemented later for
   #       all authentication methods:
@@ -112,7 +110,7 @@ function session_login_valid($form_loginname,
     }
   else if($usr['user_pw'] == 'SSH') 
     {
-      fb('This user is known but we have no way to authenticate her/him. <br />Please ask for a password to <a href="mailto:'.$GLOBALS['sys_email_adress'].'">'.$GLOBALS['sys_email_adress'].'</a>.', 1);
+      fb('This user is known but we have no way to authenticate her/him. Please ask for a password to site administrators', 1);
       return false;
       
     }
@@ -190,7 +188,6 @@ function session_login_valid($form_loginname,
 
 function session_checkip($oldip,$newip) 
 {
-  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':session_checkip($oldip,$newip) ';
   $eoldip = explode(".",$oldip);
   $enewip = explode(".",$newip);
   
@@ -207,20 +204,17 @@ function session_checkip($oldip,$newip)
 
 function session_issecure() 
 {
-  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':session_issecure() ';
   return (getenv('HTTPS') == 'on');
 }
 
 
 function session_needsstayinssl()    
 {
-  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':session_needsstayinssl()    '; 
   return db_result(db_query("SELECT stay_in_ssl FROM session WHERE session_hash='$GLOBALS[session_hash]'"), 0, 'stay_in_ssl');
 }
 
 function session_cookie($n,$v,$cookie_for_a_year=0) 
 {
-  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':session_cookie() ';
   
   # yeupou--gnu.org 2004-09-21: this will pose problem on different servers
   # with the same domain; on the other hand, it's helpful for servers that
@@ -254,7 +248,6 @@ function session_delete_cookie($n)
 
 function session_redirect($loc) 
 {
-  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':session_redirect($loc) ';
   header('Location: http' . (session_issecure()?'s':'') . '://' . (session_issecure()?$GLOBALS['sys_https_host']:$GLOBALS['sys_default_domain']).$loc);
   print("\n\n");
   exit;
@@ -262,7 +255,6 @@ function session_redirect($loc)
 
 function session_require_test($req) 
 {
-  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':session_require_test($req) ';
   /* 
        Similiar tho session_require but only return 1 or 0
   */
@@ -307,7 +299,6 @@ function session_require_test($req)
 
 function session_require($req) 
 {
-  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':session_require($req) ';
   /*
 		SV admins always return true
   */
@@ -357,7 +348,6 @@ function session_require($req)
 
 function session_setglobals($user_id) 
 {
-  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':session_setglobals($user_id) ';
   global $G_USER;
   
   #	unset($G_USER);
@@ -384,7 +374,6 @@ function session_setglobals($user_id)
 
 function session_set_new($user_id, $cookie_for_a_year=0, $stay_in_ssl=1) 
 {
-  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':session_set_new($user_id, $cookie_for_a_year=0, $stay_in_ssl=1) ';
   global $G_SESSION;
   
   #	unset($G_SESSION);
@@ -420,7 +409,6 @@ function session_set_new($user_id, $cookie_for_a_year=0, $stay_in_ssl=1)
 
 function session_set() 
 {
-  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':session_set() ';
   global $G_SESSION,$G_USER;
   
   #	unset($G_SESSION);
