@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: general.php,v 1.36 2005/09/29 11:50:42 yeupou Exp $
+# $Id: general.php 5187 2005-12-01 16:22:29Z yeupou $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2001-2002 (c) Laurent Julliard, CodeX Team, Xerox
@@ -30,7 +30,6 @@
 # requested. If the file start with ?, it's an index.
 function trackers_include()
 {
-  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':trackers_include() ';
   # Keep the dirname only if it's admin
   $dir = get_module_include_dir($GLOBALS['PHP_SELF'], 0, 1);
   if ($dir != "admin")
@@ -46,10 +45,24 @@ function trackers_include()
   return $pre."../include/trackers_run/".$dir.basename($GLOBALS['PHP_SELF']);
 }
 
+# Does like trackers_include() but load an arbitrary page of the common
+# tracker code. This is useful for trackers that have non-standard behavior
+# needs to present some standard page inside a non standard location
+function trackers_bastardinclude($page, $is_admin_page='0')
+{
+  unset($pre);
+  if ($is_admin_page)
+    {
+      $pre = "../";
+    }
+
+  return $pre."../include/trackers_run/".$page.".php";
+}
+
+
 # Generate URL arguments from a variable wether scalar or array
 function trackers_convert_to_url_arg($varname, $var)
 {
-  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':trackers_convert_to_url_arg($varname, $var)';
 
   if (is_array($var))
     {
@@ -68,7 +81,6 @@ function trackers_convert_to_url_arg($varname, $var)
 
 function trackers_header($params)
 {
-  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':trackers_header($params)';
   global $group_id,$is_bug_page,$DOCUMENT_ROOT,$advsrch;
 
   #used so the search box will add the necessary element to the pop-up box
@@ -77,7 +89,7 @@ function trackers_header($params)
 
   #required params for site_project_header();
   $params['group']=$group_id;
-  $params['toptab']=ARTIFACT;
+  $params['context']=ARTIFACT;
 
   $project=project_get_object($group_id);
 
@@ -89,13 +101,12 @@ function trackers_header($params)
     {
       exit_error(_("This project has turned off this tracker."));
     }
-  echo site_project_header($params);
+  print site_project_header($params);
 
 }
 
 function trackers_header_admin($params)
 {
-  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':trackers_header_admin($params)';
   global $group_id,$is_bug_page,$DOCUMENT_ROOT;
 
   #used so the search box will add the necessary element to the pop-up box
@@ -103,7 +114,7 @@ function trackers_header_admin($params)
 
   #required params for site_project_header();
   $params['group']=$group_id;
-  $params['toptab']='a'.ARTIFACT;
+  $params['context']='a'.ARTIFACT;
 
   $project=project_get_object($group_id);
 
@@ -115,32 +126,28 @@ function trackers_header_admin($params)
     {
       exit_error(_("This project has turned off this tracker."));
     }
-  echo site_project_header($params);
+  print site_project_header($params);
 }
 
 function trackers_footer($params)
 {
-  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':trackers_footer($params)';
   site_project_footer($params);
 }
 
 function trackers_init($group_id)
 {
-  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':trackers_init($group_id)';
   # Set the global arrays for faster processing at init time
   trackers_data_get_all_fields($group_id, true);
 }
 
 function trackers_report_init($group_id, $report_id)
 {
-  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':trackers_report_init($group_id, $report_id)';
   # Set the global array with report information for faster processing
   trackers_data_get_all_report_fields($group_id, $report_id, true);
 }
 
 function trackers_list_all_fields($sort_func=false,$by_field_id=false)
 {
-  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':trackers_list_all_fields($sort_func=false,$by_field_id=false)';
   global $BF_USAGE_BY_ID, $BF_USAGE_BY_NAME, $AT_START;
 
   # If its the first element we fetch then apply the sort
@@ -176,11 +183,10 @@ function trackers_list_all_fields($sort_func=false,$by_field_id=false)
 
 function trackers_field_label_display ($field_name, $group_id,$break=false,$ascii=false, $tab=25)
 {
-  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':trackers_field_label_display($field_name, $group_id,$break=false,$ascii=false)';
   $label = trackers_data_get_label($field_name).':';
 
   if (!$ascii)
-    { $output = '<font class="preinput"><font class="help" title="'.trackers_data_get_description($field_name).'">'.$label.'</font></font>'; }
+    { $output = '<span class="preinput"><span class="help" title="'.trackers_data_get_description($field_name).'">'.$label.'</span></span>'; }
 
   if ($break)
     { $output .= ($ascii?"\n":'<br />'); }
@@ -212,7 +218,6 @@ function trackers_field_display ($field_name,
                                  $show_unknown=false,
 				 $tab=25)
 {
-  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':trackers_field_display  ';
   /*
           Display a bug field either as a read-only value or as a read-write
           making modification possible
@@ -311,7 +316,7 @@ function trackers_field_display ($field_name,
 	else
 	  {
 	    $output .= trackers_field_date($field_name,
-					   (($value == 0) ? '' : format_date("Y-m-j",$value,'')));
+					   (($value == 0) ? '' : strftime("%Y-%m-%d",$value)));
 	  }
 	}
       break;
@@ -339,7 +344,6 @@ function trackers_field_display ($field_name,
 
 function trackers_field_date($field_name,$value='',$size=0,$maxlength=0,$ro=false)
 {
-  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':trackers_field_date';
 
   # value is formatted as Y-m-d
   list($year, $month, $day) = split("-", $value);
@@ -372,7 +376,6 @@ function trackers_field_date($field_name,$value='',$size=0,$maxlength=0,$ro=fals
 
 function trackers_multiple_field_date($field_name,$date_begin='',$date_end='',$size=0,$maxlength=0,$ro=false)
 {
-  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':trackers_multiple_field_date';
 
   # CAUTION!!!! The Javascript below assumes that the date always appear
   # in a field called 'bug_form'
@@ -408,7 +411,6 @@ function trackers_multiple_field_date($field_name,$date_begin='',$date_end='',$s
 
 function trackers_field_date_operator($field_name,$value='',$ro=false)
 {
-  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':trackers_field_date_operator ';
 
   if ($ro)
     $html = htmlspecialchars($value);
@@ -424,23 +426,30 @@ function trackers_field_date_operator($field_name,$value='',$ro=false)
 
 function trackers_field_text($field_name,$value='',$size=0,$maxlength=0)
 {
-  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':trackers_field_text';
 
   if (!$size || !$maxlength)
     list($size, $maxlength) = trackers_data_get_display_size($field_name);
 
-  $html = '<INPUT TYPE="text" name="'.$field_name.
-     '" size="'.$size.'" MAXLENGTH="'.$maxlength.'" VALUE="'.$value.'">';
+  $html = '<input type="text" name="'.$field_name.
+     '" size="'.$size.'" maxlength="'.$maxlength.'" value="'.$value.'">';
   return($html);
 
 }
 
 function trackers_field_textarea($field_name,$value='',$cols=0,$rows=0)
 {
-  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':trackers_field_textarea ';
 
   if (!$cols || !$rows)
-    list($cols, $rows) = trackers_data_get_display_size($field_name);
+    {
+      list($cols, $rows) = trackers_data_get_display_size($field_name);
+
+      # Nothing defined for this field? Use hardcoded default values
+      if (!$cols || !$rows)
+	{
+	  $cols = "65";
+	  $rows = "16";
+	}
+    }
 
   $html = '<textarea name="'.$field_name.
      '" rows="'.$rows.'" cols="'.$cols.'" wrap="soft">'.$value.'</textarea>';
@@ -459,7 +468,6 @@ function trackers_field_box ($field_name,
 			     $allowed_transition_only=false,
 			     $show_unknown=false)
 {
-  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':trackers_field_box ';
 
   # Returns a select box populated with field values for this project
   # if box_name is given then impose this name in the select box
@@ -546,18 +554,22 @@ function trackers_field_box ($field_name,
     }
 }
 
-function trackers_multiple_field_box($field_name,$box_name='',$group_id,$checked=false,$show_none=false,$text_none='None',$show_any=false, $text_any='Any',$show_value=false)
+function trackers_multiple_field_box($field_name,
+				     $box_name='',
+				     $group_id,
+				     $checked=false,
+				     $show_none=false,
+				     $text_none='None',
+				     $show_any=false,
+				     $text_any='Any',
+				     $show_value=false)
 {
-  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':trackers_multiple_field_box )';
-
   # Returns a multiplt select box populated with field values for this project
   # if box_name is given then impose this name in the select box
-  # of the  HTML form otherwise use the field_name)
+  # of the  HTML form otherwise use the field_name
 
   if (!$group_id)
-    {
-      return 'ERROR - no group_id';
-    }
+    { return _("Internal error: no group id"); }
   else
     {
       $result = trackers_data_get_field_predefined_values($field_name,$group_id,$checked);
@@ -570,9 +582,37 @@ function trackers_multiple_field_box($field_name,$box_name='',$group_id,$checked
     }
 }
 
+# Similar to trackers_multiple_field_box except that it will use checkboxes
+# instead of a multiple select field. Multiple select field is nice for
+# expert users, but it is not simple user-friendly, unlike checkboxes.
+function trackers_multiple_field_box2 ($field_name,
+				       $box_name='',
+				       $group_id,
+				       $checked=false,
+				       $show_none=false,
+				       $text_none='None',
+				       $show_any=false,
+				       $text_any='Any',
+				       $show_value=false)
+{
+  if (!$group_id)
+    { return _("Internal error: no group id"); }
+  else
+    {
+      $result = trackers_data_get_field_predefined_values($field_name,$group_id,$checked);
+
+      if ($box_name == '')
+	{
+	  $box_name = $field_name.'[]';
+	}
+      return html_build_checkbox($result,$box_name,$checked,6,$show_none,$text_none, $show_any,$text_any,$show_value);
+    }
+
+
+}
+
 function trackers_extract_field_list($post_method=true)
 {
-  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':trackers_extract_field_list($post_method=true)';
 
   global $HTTP_GET_VARS, $HTTP_POST_VARS, $BF_USAGE_BY_NAME;
   /*
@@ -607,13 +647,13 @@ function trackers_extract_field_list($post_method=true)
 	      elseif ($field_name_part == 'year')
 		{ $vfl[$field_name] = "$val-$month-$day"; }
 	    }
-	  elseif (isset($BF_USAGE_BY_NAME[$key]))
+	  elseif (isset($BF_USAGE_BY_NAME[$key]) || $key == 'comment')
 	    {
 	      $vfl[$key] = $val;
 	    }
 	  else
 	    {
-	      #dbg("Rejected key = ".$key." val = $val");
+	      dbg("Rejected key = ".$key." val = $val");
 	    }
 	}
     }
@@ -637,7 +677,7 @@ function trackers_extract_field_list($post_method=true)
 	      elseif ($field_name_part == 'year')
 		{ $vfl[$field_name] = "$val-$month-$day"; }
 	    }
-	  elseif (isset($BF_USAGE_BY_NAME[$key]))
+	  elseif (isset($BF_USAGE_BY_NAME[$key]) || $key == 'comment')
 	    {
 	      $vfl[$key] = $val;
 	    }
@@ -653,26 +693,26 @@ function trackers_extract_field_list($post_method=true)
 
 # Check whether a field was shown to the submitter
 # (useful if a field is mandatory if shown to the submitter)
-function trackers_check_is_shown_to_submitter ($field_name, $group_id, $submitter_id) 
+function trackers_check_is_shown_to_submitter ($field_name, $group_id, $submitter_id)
 {
   if ($submitter_id == 100)
     {
       # Anonymous user
-      if (trackers_data_is_showed_on_add_nologin($field_name)) 
+      if (trackers_data_is_showed_on_add_nologin($field_name))
 	{ return true; }
-    } 
-  else 
+    }
+  else
     {
-      if (!member_check($submitter_id, $group_id)) 
+      if (!member_check($submitter_id, $group_id))
 	{
           # Not a member of the group
-	  if (trackers_data_is_showed_on_add($field_name)) 
+	  if (trackers_data_is_showed_on_add($field_name))
 	    { return true; }
-	} 
+	}
       else
 	{
           # Group member
-	  if (trackers_data_is_showed_on_add_members($field_name)) 
+	  if (trackers_data_is_showed_on_add_members($field_name))
 	    { return true; }
 	}
     }
@@ -689,7 +729,7 @@ function trackers_check_empty_fields($field_array, $new_item=true)
   unset($previous_form_bad_fields);
   global $previous_form_bad_fields;
   $previous_form_bad_fields = array();
-  
+
 
   reset($field_array);
   while (list($field_name, $val) = each($field_array))
@@ -701,12 +741,12 @@ function trackers_check_empty_fields($field_array, $new_item=true)
       # done if at some point we feel the need for one more exception.
       if ($field_name == "percent_complete")
 	{ continue; }
-      
+
       # Check if it is empty
       $is_empty = (trackers_data_is_select_box($field_name) ? ($val==100) : ($val==''));
       if (!$is_empty)
 	{ continue; }
-      
+
       # Check if it is mandatory
       $mandatory_flag = trackers_data_mandatory_flag($field_name);
       unset($is_mandatory);
@@ -727,39 +767,39 @@ function trackers_check_empty_fields($field_array, $new_item=true)
 	  # ($mandatory_flag = 0)
 	  $is_mandatory = 1;
 	}
-      else 
+      else
 	{
 	  # Mandatory when shown to the submitter, we are updating an item
 	  # ($mandatory_flag = 0)
-	  
+
 	  global $item_id, $group_id, $mandatorycheck_submitter_id;
 	  if (!$mandatorycheck_submitter_id)
 	    {
-	      # Save that information for further mandatory checks, 
+	      # Save that information for further mandatory checks,
 	      # to avoid avoid a SQL request per field checked
 	      $submitter_sql = "SELECT submitted_by FROM ".ARTIFACT." WHERE bug_id='$item_id' AND group_id='$group_id'";
 	      $submitter_res = db_query($submitter_sql);
 	      $mandatorycheck_submitter_id = db_result($submitter_res,0,'submitted_by');
 	    }
-	  
+
 	  if (trackers_check_is_shown_to_submitter($field_name, $group_id, $mandatorycheck_submitter_id))
 	    {
 	      $is_mandatory = 1;
 	    }
 	}
-	
+
       if ($is_mandatory)
 	{
 	  $value = trackers_data_get_label($field_name);
 	  $previous_form_bad_fields[$field_name] = $value;
 	}
-    } 
+    }
 
   if (count($previous_form_bad_fields) > 0)
     {
       # If not_new_item is true, it mean that there was no previous value to
       # reset the entry.
-      if ($new_item) 
+      if ($new_item)
 	{
 	  fb(sprintf(ngettext("The field '%s' is mandatory. Fill it and re-submit the form.","The fields '%s' are mandatory. Fill them and re-submit the form.", count($previous_form_bad_fields)), join(', ',$previous_form_bad_fields)), 1);
 	}
@@ -779,7 +819,6 @@ function trackers_check_empty_fields($field_array, $new_item=true)
 
 function trackers_canned_response_box ($group_id,$name='canned_response')
 {
-  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':trackers_canned_response_box ';
   if (!$group_id)
     {
       fb(_("Error, no group_id"),1);
@@ -816,7 +855,6 @@ function trackers_canned_response_box ($group_id,$name='canned_response')
 
 function trackers_build_notification_matrix($user_id)
 {
-  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':trackers_build_notification_matrix($user_id)';
   # Build the notif matrix indexed with roles and events labels (not id)
   $res_notif = trackers_data_get_notification_with_labels($user_id);
   while ($arr = db_fetch_array($res_notif))
@@ -829,7 +867,6 @@ function trackers_build_notification_matrix($user_id)
 
 function trackers_check_notification($user_id, $role, $changes=false)
 {
-  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':trackers_check_notification($user_id, $role, $changes=false)';
 
   $send = false;
   $arr_notif = trackers_build_notification_matrix($user_id);
@@ -987,7 +1024,6 @@ function trackers_check_notification($user_id, $role, $changes=false)
 
 function trackers_build_notification_list($item_id, $group_id, $changes)
 {
-  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':trackers_build_notification_list($item_id, $group_id, $changes)';
 
   $sql="SELECT assigned_to, submitted_by from ".ARTIFACT." WHERE bug_id='$item_id'";
   $res_as=db_query($sql);
@@ -1104,25 +1140,27 @@ function trackers_build_notification_list($item_id, $group_id, $changes)
 
 }
 
-function trackers_mail_followup ($item_id,$more_addresses=false,$changes=false,$force_exclude_list=false)
+function trackers_mail_followup ($item_id,$more_addresses=false,$changes=false,$force_exclude_list=false, $artifact=0)
 {
-  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':trackers_mail_followup($item_id,$more_addresses=false,$changes=false)';
   global $sys_datefmt;
 
-  $sql="SELECT * from ".ARTIFACT." WHERE bug_id='$item_id'";
+  if (!$artifact)
+    { $artifact = ARTIFACT; }
+
+  $sql="SELECT * from $artifact WHERE bug_id='$item_id'";
 
   $result = db_query($sql);
-  $bug_href = "http://".$GLOBALS['sys_default_domain'].$GLOBALS['sys_home'].ARTIFACT."/?func=detailitem&item_id=$item_id";
+  $bug_href = "http://".$GLOBALS['sys_default_domain'].$GLOBALS['sys_home']."$artifact/?func=detailitem&item_id=$item_id";
 
   if ($result && db_numrows($result) > 0)
   {
 
   $group_id = db_result($result,0,'group_id');
- 
+
   unset($content_type);
   # CERN SPECIFIC (at least for now) BEGIN '
   # Maybe later we ll implement a way to select mail templates, or prepared
-  # mail format (like: text / html). 
+  # mail format (like: text / html).
   # But it will have to be done in a well planned way that take into account
   # necessary cases and is not encumbered by very very specific things.
   # Until this happen, cern will use its own functions to deals with notif.
@@ -1131,18 +1169,18 @@ function trackers_mail_followup ($item_id,$more_addresses=false,$changes=false,$
   # To ease maintainance, such specific things should usually not be added.
   # Please write to savane-dev if you intend to make such changes.
   # The upstream code cannot be cluttered by tons of things like that.
-  # This is a one time exception, or almost, needed because this cannot 
-  # be directly merged in a generic way right now. 
+  # This is a one time exception, or almost, needed because this cannot
+  # be directly merged in a generic way right now.
   if ($GLOBALS['sys_default_domain'] == "savannah.cern.ch" || $GLOBALS['sys_debug_cerntest'])
   {
     $content_type = group_get_preference($group_id, "notif_content");
-    if ($content_type == "") 
-     { 
+    if ($content_type == "")
+     {
        $content_type = '2';   # by default select maximum
-     } 
-     
+     }
+
     # Now, if the content type is 0, go on with Savane standard notif.
-    # If it s something else, use trackers_mail_followup_cernspecifichack() 
+    # If it s something else, use trackers_mail_followup_cernspecifichack()
     if ($content_type > 0)
      {
        return trackers_mail_followup_cernspecifichack($group_id,$bug_href,$result,$content_type,$item_id,$more_addresses,$changes,$force_exclude_list);
@@ -1231,7 +1269,7 @@ function trackers_mail_followup ($item_id,$more_addresses=false,$changes=false,$
       # If the item is private, take into account the exclude-list
       if (db_result($result,0,'privacy') == '2')
         {
-           $exclude_list = db_result(db_query("SELECT ".ARTIFACT."_private_exclude_address FROM groups WHERE group_id='$group_id'"),0, ARTIFACT."_private_exclude_address");
+           $exclude_list = db_result(db_query("SELECT ".$artifact."_private_exclude_address FROM groups WHERE group_id='$group_id'"),0, $artifact."_private_exclude_address");
 
         }
 
@@ -1245,7 +1283,7 @@ function trackers_mail_followup ($item_id,$more_addresses=false,$changes=false,$
       }
 
 
-      sendmail_mail($from, $to, $subject, $body, group_getunixname($group_id), ARTIFACT, $item_id, 0, 0, $exclude_list);
+      sendmail_mail($from, $to, $subject, $body, group_getunixname($group_id), $artifact, $item_id, 0, 0, $exclude_list);
       # Useless feedback, already added by sendmail_mail()
       #fb(_("Item update sent."));
 
@@ -1266,7 +1304,6 @@ function trackers_attach_file($item_id,
                               $file_description,
 			      &$changes)
 {
-  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':trackers_attach_file($item_id,';
 
 
   $user_id = (user_isloggedin() ? user_getid(): 100);
@@ -1296,8 +1333,8 @@ function trackers_attach_file($item_id,
       return false;
     }
 
-  $sql = 'INSERT into '.ARTIFACT.'_file (bug_id,submitted_by,date,description, file,filename,filesize,filetype) '.
-     "VALUES ($item_id,$user_id,'".time()."','".htmlspecialchars($file_description).
+  $sql = 'INSERT into trackers_file (item_id,artifact,submitted_by,date,description, file,filename,filesize,filetype) '.
+     "VALUES ($item_id,'".ARTIFACT."',$user_id,'".time()."','".htmlspecialchars($file_description).
      "','$data','$input_file_name','$input_file_size','$input_file_type')";
 
   $res = db_query($sql);
@@ -1314,7 +1351,7 @@ function trackers_attach_file($item_id,
       $changes['attach']['description'] = $file_description;
       $changes['attach']['name'] = $input_file_name;
       $changes['attach']['size'] = $input_file_size;
-      $changes['attach']['href'] = 'http://'.$GLOBALS['sys_default_domain'].$GLOBALS['sys_home'].ARTIFACT."/download.php?item_id=$item_id&item_file_id=$file_id";
+      $changes['attach']['href'] = 'http://'.$GLOBALS['sys_default_domain'].$GLOBALS['sys_home'].ARTIFACT."/download.php?file_id=$file_id";
       trackers_data_add_history("Attached File",
 				"-",
 				"Added ".$input_file_name.", #".$file_id,
@@ -1326,7 +1363,6 @@ function trackers_attach_file($item_id,
 
 function trackers_exist_cc($item_id,$cc)
 {
-  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':trackers_exist_cc($item_id,$cc)';
   $sql = "SELECT bug_cc_id FROM ".ARTIFACT."_cc WHERE bug_id='$item_id' AND email='$cc'";
   $res = db_query($sql);
   return (db_numrows($res) >= 1);
@@ -1334,7 +1370,6 @@ function trackers_exist_cc($item_id,$cc)
 
 function trackers_insert_cc($item_id,$cc,$added_by,$comment,$date)
 {
-  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':trackers_insert_cc($item_id,$cc,$added_by,$comment,$date)';
   $sql = "INSERT INTO ".ARTIFACT."_cc (bug_id,email,added_by,comment,date) ".
      "VALUES ('$item_id','$cc','$added_by','$comment','$date')";
   $res = db_query($sql);
@@ -1350,7 +1385,6 @@ function trackers_insert_cc($item_id,$cc,$added_by,$comment,$date)
 
 function trackers_add_cc($item_id,$group_id,$email,$comment,&$changes)
 {
-  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':trackers_add_cc($item_id,$group_id,$email,$comment)';
   global $feedback,$ffeedback;
 
   $user_id = (user_isloggedin() ? user_getid(): 100);
@@ -1384,7 +1418,6 @@ function trackers_add_cc($item_id,$group_id,$email,$comment,&$changes)
 
 function trackers_delete_cc($group_id=false,$item_id=false,$item_cc_id=false)
 {
-  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':trackers_delete_cc($group_id=false,$item_id=false,$item_cc_id=false)';
   global $feedback,$ffeedback;
 
   # If both bug_id and bug_cc_id are given make sure the cc belongs
@@ -1421,7 +1454,6 @@ function trackers_delete_cc($group_id=false,$item_id=false,$item_cc_id=false)
 
 function trackers_delete_dependancy ($group_id, $item_id, $item_depends_on, $item_depends_on_artifact, &$changes)
 {
-  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':trackers_delete_dependancy ($group_id, $item_id, $item_depends_on, $item_depends_on_artifact)';
 
   # Can be done only by at least technicians
   # Note that is it possible to fake the system by providing a false group_id.
@@ -1467,7 +1499,6 @@ function trackers_delete_dependancy ($group_id, $item_id, $item_depends_on, $ite
 */
 function trackers_isvarany($var)
 {
-  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':trackers_isvarany($var)';
   if (is_array($var))
     {
       reset($var);
@@ -1491,7 +1522,6 @@ function trackers_isvarany($var)
 # simply add it
 function trackers_add_sort_criteria($criteria_list, $order, $msort)
 {
-  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':trackers_add_sort_criteria($criteria_list, $order, $msort)';
   #echo "<br />DBG \$criteria_list=$criteria_list,\$order=$order";
 
   if ($criteria_list)
@@ -1543,7 +1573,6 @@ function trackers_add_sort_criteria($criteria_list, $order, $msort)
 # - is descending)
 function trackers_criteria_list_to_query($criteria_list)
 {
-  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':trackers_criteria_list_to_query($criteria_list)';
 
   $criteria_list = str_replace('>',' ASC',$criteria_list);
   $criteria_list = str_replace('<',' DESC',$criteria_list);
@@ -1554,7 +1583,6 @@ function trackers_criteria_list_to_query($criteria_list)
 # $url must not contain the morder parameter
 function trackers_criteria_list_to_text($criteria_list, $url)
 {
-  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':trackers_criteria_list_to_text($criteria_list, $url)';
 
   if ($criteria_list)
     {
@@ -1581,7 +1609,6 @@ function trackers_criteria_list_to_text($criteria_list, $url)
 
 function trackers_build_match_expression($field, &$to_match)
 {
-  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':trackers_build_match_expression($field, &$to_match)';
 
   # First get the field type
   $res = db_query("SHOW COLUMNS FROM ".ARTIFACT." LIKE '$field'");
@@ -1716,7 +1743,6 @@ function trackers_build_match_expression($field, &$to_match)
 # function moved to data.
 function trackers_delete_file($group_id=false,$item_id=false,$item_file_id=false)
 {
-  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':trackers_delete_file($group_id=false,$item_id=false,$item_file_id=false)';
 
   return trackers_data_delete_file($group_id, $item_id, $item_file_id);
 }
@@ -1748,7 +1774,7 @@ function trackers_get_msgid ($artifact, $item_id, $latest="")
 
   # CERN SPECIFIC (at least for now) BEGIN '
   # Maybe later we ll implement a way to select mail templates, or prepared
-  # mail format (like: text / html). 
+  # mail format (like: text / html).
   # But it will have to be done in a well planned way that take into account
   # necessary cases and is not encumbered by very very specific things.
   # Until this happen, cern will use its own functions to deals with notif.
@@ -1757,8 +1783,8 @@ function trackers_get_msgid ($artifact, $item_id, $latest="")
   # To ease maintainance, such specific things should usually not be added.
   # Please write to savane-dev if you intend to make such changes.
   # The upstream code cannot be cluttered by tons of things like that.
-  # This is a one time exception, or almost, needed because this cannot 
-  # be directly merged in a generic way right now. 
+  # This is a one time exception, or almost, needed because this cannot
+  # be directly merged in a generic way right now.
 function trackers_mail_followup_cernspecifichack ($group_id, $bug_href, $result,$content_type, $item_id, $more_addresses=false, $changes=false,$force_exclude_list=false) {
   global $sys_datefmt;
 
@@ -1770,14 +1796,14 @@ if ($content_type == '2') {   # for now means CERN present format
 
   $body = "This is an automated notification sent by ".$GLOBALS['sys_name']. ".
 It relates to:\n\t\t".ARTIFACT." #".$item_id.", project ".group_getname($group_id)."\n";
-      
+
       if ($changes)
 	{
 	  $body .= "\n==============================================================================\n";
 	  $body .= " LATEST MODIFICATIONS of ".ARTIFACT." #".$item_id.":\n";
           $body .= "==============================================================================\n\n";
 
-      
+
    ### format_item_changes of savane 1.0.6
  # FIXME: strange, with %25s it does not behave exactly like
   # trackers_field_label_display
@@ -1794,9 +1820,9 @@ It relates to:\n\t\t".ARTIFACT." #".$item_id.", project ".group_getname($group_i
       if (!$h['del'] && !$h['add'])
 	{ continue; }
 
-      if ($field == "details" || $field == "attach") 
+      if ($field == "details" || $field == "attach")
         { continue; }
-     
+
       $label = trackers_data_get_label($field);
       if (!$label)
 	{ $label = $field; }
@@ -1818,7 +1844,7 @@ It relates to:\n\t\t".ARTIFACT." #".$item_id.", project ".group_getname($group_i
 
       $out_com = "Follow-up Comment #".db_numrows(trackers_data_get_followups($item_id));
       if (!$out)
-        { 
+        {
           $out_com .= ", ".utils_get_tracker_prefix(ARTIFACT)." #".$item_id." (project ".group_getunixname($group_id).")";
         }
 
@@ -1841,7 +1867,7 @@ It relates to:\n\t\t".ARTIFACT." #".$item_id.", project ".group_getname($group_i
 
       $out_att = "Additional Item Attachment";
       if (!$out)
-        { 
+        {
           $out_att .= ", ".utils_get_tracker_prefix(ARTIFACT)." #".$item_id." (project ".group_getunixname($group_id).")";
         }
       $out_att .= ":\n\n";
@@ -1867,34 +1893,34 @@ It relates to:\n\t\t".ARTIFACT." #".$item_id.", project ".group_getname($group_i
       $body .= sprintf("%25s", "Project:").' '.group_getname($group_id)."\n";
       $body .= trackers_field_display('submitted_by', $group_id, db_result($result,0,'submitted_by'),false,true,true,true)."\n";
       $body .= trackers_field_display('date', $group_id, db_result($result,0,'date'),false,true,true,true)."\n";
-      
-      # All other regular fields now		 
+
+      # All other regular fields now
       $i=0;
       while ($field_name = trackers_list_all_fields())
 	{
-	  
-	  # if the field is a special field or if not used by his project 
+
+	  # if the field is a special field or if not used by his project
 	  # then skip it. Otherwise print it in ASCII format.
 	  if (!trackers_data_is_special($field_name) &&
 	      trackers_data_is_used($field_name))
 	    {
-	      
+
 	      $body .= trackers_field_display($field_name,
 					      $group_id,
 					      db_result($result,0,$field_name),
 					      false,
 					      true,
 					      true,
-					      true);			      
-	      
+					      true);
+
 	      $i++;
 	      $body .= "\n";
 	    }
 	}
       $body .= "\n";
-						   
+
       # Now display other special fields
-      $body .= "    _______________________________________________________\n\n".trackers_field_display('details', 
+      $body .= "    _______________________________________________________\n\n".trackers_field_display('details',
 	                               $group_id,
 				       db_result($result,0,'details'),
                                        true,true,true,true);
@@ -1902,7 +1928,7 @@ It relates to:\n\t\t".ARTIFACT." #".$item_id.", project ".group_getname($group_i
       # Then output the history of bug details from newest to oldest
       $body .= "\n\n";
       # format_item_details($item_id, $group_id, true); of savane 1.0.6
-      $result=trackers_data_get_followups($item_id); 
+      $result=trackers_data_get_followups($item_id);
       $rows=db_numrows($result);
 
   # No followup comment -> return now
@@ -1910,17 +1936,17 @@ It relates to:\n\t\t".ARTIFACT." #".$item_id.", project ".group_getname($group_i
     {
        unset($out);
       $out .= "    _______________________________________________________\n\nFollow-up Comments:\n\n";
-     
+
   # Loop throuh the follow-up comments and format them
   for ($i=0; $i < $rows; $i++)
     {
-       
+
       $comment_type = db_result($result, $i, 'comment_type');
-      if ($comment_type == 'None') 
+      if ($comment_type == 'None')
 	{ $comment_type = ''; }
       else
 	{ $comment_type = '['.$comment_type.']'; }
-	
+
     	  $fmt = "\n-------------------------------------------------------\n".
 	     "Date: %-30sBy: %s\n";
 	  if ($comment_type)
@@ -1929,15 +1955,15 @@ It relates to:\n\t\t".ARTIFACT." #".$item_id.", project ".group_getname($group_i
 	    { $fmt .= "%s%s"; }
 	  $fmt .= "\n";
 
-	
+
       # I wish we had sprintf argument swapping in PHP3 but
       # we dont so do it the ugly way...
-			
+
          if (db_result($result, $i, 'realname'))
             {
               $name = db_result($result, $i, 'realname')." <".db_result($result, $i, 'user_name').">";
             }
-          else 
+          else
             {
               $name = "Anonymous"; # must no be translated, part of mails notifs
 				     }
@@ -1948,7 +1974,7 @@ It relates to:\n\t\t".ARTIFACT." #".$item_id.", project ".group_getname($group_i
 			  utils_unconvert_htmlspecialchars(db_result($result, $i, 'old_value'))
 			  );
 
-	  }     
+	  }
      # final touch...
      $out .=  "\n\n\n";
      $body .= $out;
@@ -1970,7 +1996,7 @@ It relates to:\n\t\t".ARTIFACT." #".$item_id.", project ".group_getname($group_i
       $fmt = "%-35s | %s\n";
       $out .= sprintf($fmt, 'CC Address', 'Comment');
       $out .= "------------------------------------+-----------------------------\n";
- 
+
   # Loop through the cc and format them
   for ($i=0; $i < $rows; $i++)
     {
@@ -2009,14 +2035,14 @@ It relates to:\n\t\t".ARTIFACT." #".$item_id.", project ".group_getname($group_i
       $out .= "    _______________________________________________________\n\nFile Attachments:\n\n";
       $fmt = "\n-------------------------------------------------------\n".
 	 "Date: %s  Name: %s  Size: %s   By: %s\n%s\n%s";
- # Loop throuh the attached files and format them 
+ # Loop throuh the attached files and format them
 
   for ($i=0; $i < $rows; $i++)
     {
 
       $item_file_id = db_result($result, $i, 'bug_file_id');
 	  $href = $GLOBALS['sys_home'].ARTIFACT."/download.php?item_id=$item_id&item_file_id=$item_file_id";
-  
+
        $out .= sprintf($fmt,
 			  format_date($sys_datefmt,db_result($result, $i, 'date')),
 			  db_result($result, $i, 'filename'),
@@ -2024,14 +2050,14 @@ It relates to:\n\t\t".ARTIFACT." #".$item_id.", project ".group_getname($group_i
 			  db_result($result, $i, 'user_name'),
 			  db_result($result, $i, 'description'),
 			  '<http://'.$GLOBALS['sys_default_domain'].utils_unconvert_htmlspecialchars($href).'>');
-		       
+
 			}
 
                 # final touch...
  		$out .= "\n";
 $body .= $out;
      }
-		       
+
       # format_item_attached_files of savane 1.0.6 end
 
 
@@ -2167,7 +2193,7 @@ if ($content_type == '1') {   # for now means ROOT wishes (UGLY ... I know!)
 # stuff is formatted
 
       # See who is going to receive the notification.
-      # Plus append any other email 
+      # Plus append any other email
       # given at the end of the list.
       $arr_addresses = trackers_build_notification_list($item_id,$group_id,$changes);
       $to = join(',',$arr_addresses);
@@ -2207,7 +2233,7 @@ if ($content_type == '1') {   # for now means ROOT wishes (UGLY ... I know!)
       # Disallow mail notification for an address, private or not
       if ($force_exclude_list)
       {
-        if ($exclude_list) 
+        if ($exclude_list)
           { $exclude_list .= ",".$force_exclude_list; }
         else
           { $exclude_list = $force_exclude_list; }
