@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: show.php,v 1.30 2005/09/12 09:31:30 yeupou Exp $
+# $Id: show.php 5187 2005-12-01 16:22:29Z yeupou $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2001-2002 (c) Laurent Julliard, CodeX Team, Xerox
@@ -24,8 +24,6 @@
 # along with the Savane project; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 
-
-
 function show_item_list ($result_arr,
 			 $offset,
 			 $total_rows,
@@ -35,7 +33,7 @@ function show_item_list ($result_arr,
 			 $url,
 			 $nolink=false)
 {
-  global $sys_datefmt,$group_id,$PHP_SELF,$chunksz,$morder;
+  global $group_id,$PHP_SELF,$chunksz,$morder;
 
   # Build the list of links to use for column headings
   # Used to trigger sort on that column
@@ -52,7 +50,7 @@ function show_item_list ($result_arr,
       Show extra rows for <-- Prev / Next -->
   */
 
-  $nav_bar ='<h3 align="center">';
+  $nav_bar ='<h3 class="nextprev">';
 
   # If all bugs on screen so no prev/begin pointer at all
   if ($total_rows > $chunksz)
@@ -131,7 +129,9 @@ function show_item_list ($result_arr,
            # If we are in digest mode, add the digest checkbox
 	  if ($field_arr[$j] == "digest")
 	    {
-	      print '<td class="center">'.form_input("checkbox", "items_for_digest[]", $thisitem_id).'</td>';
+	      # Dirty workaround to have boxes selected by default in the
+	      # form_input
+	      print '<td class="center">'.form_input("checkbox", "items_for_digest[]", "$thisitem_id\" checked=\"checked").'</td>';
 	      continue;
 	    }
 	  
@@ -154,7 +154,7 @@ function show_item_list ($result_arr,
 		  else
 		    { $highlight_date = ''; }
 		  print "<td $width$highlight_date>";
-		  print format_date($sys_datefmt,$value);
+		  print format_date('short',$value);
 		  print "</td>\n";
 		}
 	      else
@@ -199,7 +199,289 @@ function show_item_list ($result_arr,
 		    {
 		      print "<td $width>".'<a href="?func=detailitem&amp;item_id='.
 			$thisitem_id.'">'.
-			$value .'</a>&nbsp;</td>'."\n";
+			$value .'</a></td>'."\n";
+		    }
+		}
+	  
+	}
+      print "</tr>\n";
+    }
+  
+  print '</table>';
+  
+  # Print prev/next links
+  print "<br />".$nav_bar;
+
+}
+
+## 
+# Do the same a item list but in sober output
+function show_item_list_sober ($result_arr,
+			       $total_rows,
+			       $url)
+{
+  global $group_id, $sys_group_id, $sys_name;
+
+  $possible_contexts = cookbook_context_possiblevalues();
+  $possible_audiences = cookbook_audience_possiblevalues();
+  
+  # If we are on a project cookbook, take into account impossible values:
+  # recipes of features unused by the project
+  $impossible_contexts = array();
+  if ($group_id != $sys_group_id)
+    {
+      $impossible_contexts = cookbook_context_project_impossiblevalues();
+    }
+
+  
+  # Add the unset case, when the item is actually not bound to any context
+  # or action
+  # Build sql specific part for these
+  unset($sql_unboundcontext, $sql_unboundaudience);
+  $thisarray = array_merge($possible_contexts, $impossible_contexts);
+  while (list($context,) = each($thisarray))
+    { 
+      $sql_unboundcontext .= "AND context_$context='0' "; 
+    }
+  while (list($audience,) = each($possible_audiences))
+    { $sql_unboundaudience .= "AND audience_$audience='0' "; }
+
+  # Built for scratch two groups of audiences possible for this page:
+  # group members and non-group members
+  $possible_audiences = array();
+  $possible_audiences['nonmembers'] = _("Non Project Members");
+  $possible_audiences['members'] = _("Project Members");
+    
+  # Add unset cases to the arrays
+  $possible_contexts['unbound'] = _("Other");
+  $possible_audiences['unbound'] = _("Undefined");
+
+  # Build sql specific part to group audiences between:
+  #   project members / non project members
+  $sql_nonmembers = "AND (audience_anonymous='1' OR audience_loggedin='1')";
+  $sql_members = "AND (audience_members='1' OR audience_technicians='1' OR audience_managers='1')";
+
+  unset($sql_privateitem);
+
+  # Go through the list of possible context and then possible actions
+  # print relevant items
+  print '<ul>';
+  reset($possible_contexts);
+  while (list($context,$context_label) = each($possible_contexts))
+    {
+      unset($context_content);
+      reset($possible_audiences);
+      while (list($audience,$audience_label) = each($possible_audiences))
+	{
+          # Get recipes contextual data
+	  # (no limit argument, expecting people not to use terrible scales)
+	  
+	  if ($audience == 'nonmembers')
+	    {
+	      $sql_audience = $sql_nonmembers;
+	    }
+	  else
+	    {
+	      $sql_audience = $sql_members;
+	    }
+ 
+	  # Special deal for the item unbound
+	  if ($audience != 'unbound' && $context != 'unbound')
+	    {
+	      # Normal case, binds for both context and audience
+	      $sql_context = "SELECT * FROM cookbook_context2recipe WHERE (group_id='$group_id' OR group_id='$sys_group_id') AND context_$context='1' $sql_audience";
+	    }
+	  else if ($audience == 'unbound' && $context != 'unbound')
+	    {
+	      # Bind only for the context
+	      $sql_context = "SELECT * FROM cookbook_context2recipe WHERE (group_id='$group_id' OR group_id='$sys_group_id') AND context_$context='1' $sql_unboundaudience";
+	    }
+	  else if ($context == 'unbound' && $audience != 'unbound')
+	    {
+	      # Bind only for the audience
+	      $sql_context = "SELECT * FROM cookbook_context2recipe WHERE (group_id='$group_id' OR group_id='$sys_group_id') $sql_audience $sql_unboundcontext";
+	    }
+	  else if ($context == 'unbound' && $audience == 'unbound')
+	    {
+	      # Not binded at all
+	      $sql_context = "SELECT * FROM cookbook_context2recipe WHERE (group_id='$group_id' OR group_id='$sys_group_id') $sql_unboundcontext $sql_unboundaudience";
+	    }
+	  
+	  $result_context = db_query($sql_context);
+	  $result_rows = db_numrows($result_context);
+
+	  if ($result_rows)
+	    {
+	      # We want to show items sorted by alphabetical order.
+	      # We will first put the result in a an array
+	      # we will sort the array and use it to print out results.
+	      # We store the summary in lower case, to avoid having a case
+	      # sensitive sort.
+	      $thisaudience_results = array();
+	      for ($i = 0; $i < $result_rows; $i++) 
+		{
+		  $thisitem_id = db_result($result_context, $i, 'recipe_id');
+		  $thisaudience_results[$thisitem_id] = 
+		    strtolower($result_arr[$thisitem_id]["summary"]);
+		}
+	      asort($thisaudience_results);
+	      unset($audience_content);
+	      while (list($thisitem_id,$summary) = each($thisaudience_results))
+		{
+		  # Ignore if not approved
+		  if ($result_arr[$thisitem_id]["resolution_id"] != '1')
+		    { continue; }
+
+		  # Detect if it is a site wide doc item. Ignore that if we
+		  # are on the site admin group
+		  unset($is_site_doc, $url_extra_arg);
+		  if ($group_id != $sys_group_id)
+		    {
+		      if ($result_arr[$thisitem_id]["group_id"] == $sys_group_id)
+			{
+			  $is_site_doc = true;
+			  $url_extra_arg = '&amp;comingfrom='.$group_id;
+			}
+		    }
+
+
+		  $audience_content .= '<li>';
+                  # Show specific background color only for maximum priority
+		  $priority = $result_arr[$thisitem_id]["priority"];
+		  if ($priority > 4)
+		    {
+		      $audience_content .= '<span class="'.utils_get_priority_color($result_arr[$thisitem_id]["priority"]).'">';
+		    }
+		  
+		  # In this link, we need to mention from where we come from
+		  # so it is possible to know if we are actually inside a 
+		  # group cookbook if ever we look at a site wide documentation
+		  $audience_content .= utils_link($GLOBALS['sys_home'].'cookbook/?func=detailitem'.$url_extra_arg.'&amp;item_id='.$thisitem_id, $result_arr[$thisitem_id]["summary"]);
+		  if ($priority > 4)
+		    {
+		      $audience_content .= '</span>';
+		    }
+		  
+		  # If it comes from the site docs, mention it
+		  if ($is_site_doc)
+		    {
+		      $audience_content .= '&nbsp;&nbsp;<span class="smaller">('.sprintf(_("From %s User Docs"), $sys_name).')</span>';
+		    }
+		  
+		  $audience_content .= '</li>';
+		}
+
+	      # If there was valid results, save the subcontext 
+	      if (!$audience_content)
+		{ continue; }
+
+	      $context_content .= '<li><span class="smaller">'.sprintf(_("%s:"), $audience_label).'</span>';
+	      $context_content .= '<ul>';
+	      $context_content .= $audience_content;
+	      $context_content .= '</ul>';
+	      $context_content .= '</li>';
+	    }
+	}  
+      # If there was valid results, print the context 
+      if (!$context_content)
+	{ continue; }
+      
+      print '<li>'.html_anchor(sprintf(_("%s:"), $context_label), $context);
+      print '<ul>';
+      print $context_content;
+      print '</ul><br />';
+      print '</li>';
+      
+    }
+  print '</ul>';
+
+
+
+
+  
+  return true;
+  while (list(,$thisitem) = each($result_arr))
+    {
+      $thisitem_id = $thisitem['bug_id'];
+      
+      print '<tr class="'.utils_get_priority_color($result_arr[$thisitem_id]["priority"], $result_arr[$thisitem_id]["status_id"]).'">'."\n";
+      
+      for ($j=0; $j<$nb_of_fields; $j++)
+
+
+	{
+           # If we are in digest mode, add the digest checkbox
+	  if ($field_arr[$j] == "digest")
+	    {
+	      print '<td class="center">'.form_input("checkbox", "items_for_digest[]", $thisitem_id).'</td>';
+	      continue;
+	    }
+	  
+	  $value = $result_arr[$thisitem_id][$field_arr[$j]];
+	  if ($width_arr[$j])
+	    {
+	      $width = 'width="'.$width_arr[$j].'%"';
+	    }
+	  else
+	    {
+	      $width = '';
+	    }
+	  
+	  if (trackers_data_is_date_field($field_arr[$j]) )
+	    {
+	      if ($value)
+		{
+		  if ($field_arr[$j] == 'planned_close_date' and $value < time())
+		    { $highlight_date = ' class="highlight"'; }
+		  else
+		    { $highlight_date = ''; }
+		  print "<td $width$highlight_date>";
+		  print format_date('short',$value);
+		  print "</td>\n";
+		}
+	      else
+		{ print "<td align=\"middle\" $width>-</td>\n"; }
+	      
+	    }
+	  else if ($field_arr[$j] == 'bug_id')
+	    {
+	      
+	      if ($nolink)
+		{ print "<td $width>#$value</td>\n"; }
+	      else
+		    {
+		      print "<td $width>";
+		      
+		      print '<a href="?func=detailitem&amp;item_id='.$value.'">';
+		      
+		      print '&nbsp;#'.$value .'</a></td>'."\n";
+		      
+		    }
+	      
+	    }
+	  else if (trackers_data_is_username_field($field_arr[$j]))
+	    {
+	      
+	      if ($nolink)
+		{ print "<td $width>$value</td>\n"; }
+	      else
+		{ print "<td $width>".utils_user_link($value)."</td>\n"; }
+	      
+	    }
+	  else if (trackers_data_is_select_box($field_arr[$j]))
+	    {
+	      print "<td $width>". trackers_data_get_cached_field_value($field_arr[$j], $group_id, $value) .'</td>'."\n";
+	      
+	    }
+	  else
+		{
+		  if ($nolink)
+		    { print "<td $width>". $value .'&nbsp;</td>'."\n"; }
+		  else
+		    {
+		      print "<td $width>".'<a href="?func=detailitem&amp;item_id='.
+			$thisitem_id.'">'.
+			$value .'</a></td>'."\n";
 		    }
 		}
 	  
@@ -219,7 +501,6 @@ function show_item_list ($result_arr,
 # excluding details
 function show_item_history ($item_id,$group_id, $no_limit=false)
 {
-  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':show_item_history ';
   global $sys_datefmt;
   $result=trackers_data_get_history($item_id);
   $rows=db_numrows($result);
@@ -258,7 +539,15 @@ function show_item_history ($item_id,$group_id, $no_limit=false)
       for ($i=0; $i < $rows; $i++)
 	{
           $field = db_result($result, $i, 'field_name');
+
+          # If the stored label is "realdetails", it means it is the details
+          # field (realdetails is used because someone had the nasty idea to
+          # use "details" to mean "comment")
+          if ($field == "realdetails")
+            { $field = "details"; }
+
 	  $field_label = trackers_data_get_label($field);
+
           # if field_label is empty, no label was found, return as it is stored
           if (!$field_label)
             { $field_label = $field; }
@@ -300,6 +589,8 @@ function show_item_history ($item_id,$group_id, $no_limit=false)
 	  if (trackers_data_is_select_box($field))
 	    {
 	      # Its a select box look for value in clear
+              # (If we hit case of transition automatique update, show it in
+              # specific way)
               if ($value_id == "transition-other-field-update")
                 {
 	          print "-"._("Automatic update due to transitions settings")."-";
@@ -317,7 +608,7 @@ function show_item_history ($item_id,$group_id, $no_limit=false)
 	  else
 	    {
 	      # It's a text zone then display directly
-	      print $value_id;
+ 	      print $value_id;
 	    }
 
            print '</td><td class="smaller" align="center"><img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/next.png" border="0" alt="=>" /></td><td class="smaller" align="left">';
@@ -354,22 +645,19 @@ function show_item_history ($item_id,$group_id, $no_limit=false)
 
 function show_item_details ($item_id, $group_id, $ascii=false, $item_assigned_to=false,$quoted=false)
 {
-  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':show_item_details ($item_id, $group_id, $ascii=false)';
   print format_item_details($item_id,$group_id,$ascii,$item_assigned_to,$quoted);
 }
 
 
 
-function show_item_attached_files ($item_id,$group_id, $ascii=false)
+function show_item_attached_files ($item_id,$group_id, $ascii=false, $sober=false)
 {
-  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':show_item_attached_files ($item_id,$group_id, $ascii=false)';
-  print format_item_attached_files ($item_id,$group_id, $ascii);
+  print format_item_attached_files ($item_id,$group_id, $ascii, $sober);
 }
 
 
 function show_item_cc_list ($item_id,$group_id, $ascii=false)
 {
-  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':show_item_cc_list ($item_id,$group_id, $ascii=false)';
   print format_item_cc_list ($item_id,$group_id, $ascii);
 }
 
@@ -377,7 +665,6 @@ function show_item_cc_list ($item_id,$group_id, $ascii=false)
 # Look for items that $item_id depends on in all artifact
 function show_item_dependency ($item_id)
 {
-  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':show_item_dependency ($item_id)';
   return show_dependent_item($item_id, $dependson=1);
 }
 
@@ -386,7 +673,6 @@ function show_item_dependency ($item_id)
 # or look for items that $item_id depends on in all artifact.
 function show_dependent_item ($item_id, $dependson=0)
 {
-  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':show_dependent_item ($item_id, $dependson=0)';
   global $group_id;
 
   $artifacts = array("support", "bugs", "task", "patch");
