@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: add.php,v 1.28 2005/09/23 07:26:49 yeupou Exp $
+# $Id: add.php 5187 2005-12-01 16:22:29Z yeupou $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2001-2002 (c) Laurent Julliard, CodeX Team, Xerox
@@ -79,7 +79,7 @@ while ($field_name = trackers_list_all_fields())
 	  if (!$$field_name)
 	    { $field_value = trackers_data_get_default_value($field_name); }
 	  else
-	    { $field_value = $$field_name; }
+	    { $field_value = htmlspecialchars(stripslashes($$field_name)); }
 
 	  list($sz,) = trackers_data_get_display_size($field_name);
 	  $label = trackers_field_label_display($field_name,
@@ -113,12 +113,6 @@ while ($field_name = trackers_list_all_fields())
 	  
           # Fields colors
 	  unset($field_class, $row_class);
-	  if ($previous_form_bad_fields && array_key_exists($field_name, $previous_form_bad_fields))
-	    {  
-                  # We highlight fields that were not properly/completely 
-		  # filled.
-	      $field_class = ' class="highlight"';
-	    }
 	  if ($j % 2 && $field_name != 'details')
 	    {
 		  # We keep the original submission with the default
@@ -129,6 +123,20 @@ while ($field_name = trackers_list_all_fields())
 	      $row_class = ' class="'.utils_altrow($j+1).'"'; 
 	    }
 
+          # If we are working on the cookbook, present checkboxes to
+          # defines context before the summary line;
+	  if (CONTEXT == 'cookbook' && $field_name == 'summary' && $is_trackeradmin)
+	    {
+	      cookbook_print_form();
+	    }
+	  
+          # We highlight fields that were not properly/completely 
+	  # filled.
+	  if ($previous_form_bad_fields && array_key_exists($field_name, $previous_form_bad_fields))
+	    {  
+	      $field_class = ' class="highlight"';
+	    }
+
 	  if ($sz > $max_size) 
 	    {
               # Field getting one line for itself 
