@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: field_values.php,v 1.25 2005/06/30 17:19:36 toddy Exp $
+# $Id: field_values.php 5187 2005-12-01 16:22:29Z yeupou $
 #
 #  Copyright 2001-2002 (c) Laurent Julliard, CodeX Team, Xerox
 #
@@ -647,7 +647,7 @@ if ($group_id && user_ismember($group_id,'A'))
 	._("Hidden").'</option>
       </select>
       <p>
-      <span class="preinput">'._("Description: (optional)").'<br />
+      <span class="preinput">'._("Description: (optional)").'</span><br />
       <textarea name="description" rows="4" cols="65" wrap="soft">'.db_result($res,0,'description').'</textarea></p>';
 
       $count = trackers_data_count_field_value_usage($group_id, $field, db_result($res,0,'value_id'));
