@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: field_values_transition-ofields-update.php,v 1.3 2005/06/30 17:19:36 toddy Exp $
+# $Id: field_values_transition-ofields-update.php 5187 2005-12-01 16:22:29Z yeupou $
 #
 #  Copyright      2004 (c) Mathieu Roy <yeupou--at--gnu.org>
 #                          Yves Perrin <yves.perrin--at--cern.ch>
@@ -99,7 +99,7 @@ if ($group_id && member_check(0,$group_id,'A'))
   
 
   trackers_header_admin(array('title'=>_("Field Values Transitions: Others Fields Update")));
-  print '<h3>'.sprintf(_("Others Fields to update when '%s' change from '%s' to '%s':"),utils_link($GLOBALS['sys_home'].ARTIFACT.'/admin/field_values.php?group='.$group_name.'&list_value=1&field='.$field,trackers_data_get_label($field)),$from,$to).'</h3>';
+  print '<h3>'.sprintf(_("Others Fields to update when '%s' change from '%s' to '%s':"), trackers_data_get_label($field),$from,$to).'</h3>';
   
   print '<p class="warn">'.sprintf(_("Note that if you set an automatic update of the field %s, technicians will be able to close items by changing the value of the field %s."),trackers_data_get_label('status_id'),trackers_data_get_label($field)).'</p>';
   print '<p>'._("Note also the automatic update process will not override field values specifically filled in forms. It means that if someone was able (depending on his role in the project) to modify/set a specific field value, any automatic update supposed to apply to this field will be disregarded.").'</p>';
