@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: detail.php,v 1.50 2005/09/11 13:39:32 yeupou Exp $
+# $Id: detail.php 5187 2005-12-01 16:22:29Z yeupou $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2001-2002 (c) Laurent Julliard, CodeX Team, Xerox
@@ -24,7 +24,6 @@
 # You should have received a copy of the GNU General Public License
 # along with the Savane project; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
-
  
 $sql="SELECT * FROM ".ARTIFACT." WHERE bug_id='$item_id' AND group_id='$group_id'";
 $fields_per_line=2;
@@ -263,10 +262,10 @@ if (db_numrows($result) > 0)
      printf (_("(Note: you can add pointers to others items by typing %s where %s is one of %s and %s the item id number.)"), 
 	  "<font class=\"italic\">artifact #nnn</font>",
 	  "<font class=\"italic\">artifact</font>",
-	  "<font class=\"italic\">support, bug, task, patch</font>",
+	  "<font class=\"italic\">support, bug, task, patch, recipe, file</font>",
 	  "<font class=\"italic\">nnn</font>");
      print '<p>&nbsp;&nbsp;&nbsp;';
-     print trackers_field_textarea('details','');
+     print trackers_field_textarea('comment','');
      print '<p>';
 
      if (!user_isloggedin()) 
