@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: index.php,v 1.45 2005/09/28 08:01:15 yeupou Exp $
+# $Id: index.php 5187 2005-12-01 16:22:29Z yeupou $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2001-2002 (c) Laurent Julliard, CodeX Team, Xerox
@@ -25,12 +25,8 @@
 # along with the Savane project; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 
-if ($item_id && !$group_id)
-{
-# If the group information is missing, try to guess it
-# from the item_id given
-  $group_id = trackers_data_get_item_group($item_id);
-}
+# This page does not give access to sober mode
+unset($sober);
 
 if ($group_id)
 {
@@ -40,8 +36,7 @@ if ($group_id)
   $project=project_get_object($group_id);
   $changed = false;
   $changes = array();
-  unset($browse_preamble);
-  unset($previous_form_bad_fields);
+  unset($browse_preamble, $previous_form_bad_fields, $sober);
 
   switch ($func)
     {
@@ -135,22 +130,23 @@ if ($group_id)
             # Attach new file if there is one
 	    if ($input_file != "none" && $input_file)
 	      {
-		trackers_attach_file($item_id,
-				     $group_id,
-				     $input_file,
-				     $input_file_name, # 4
-				     $input_file_type,
-				     $input_file_size, #6
-				     $file_description,
-				     $changes);
+		$changed |= trackers_attach_file($item_id,
+						 $group_id,
+						 $input_file, 
+						 $input_file_name, # 4
+						 $input_file_type,
+						 $input_file_size, # 6
+						 $file_description,
+						 $changes);
+
 	      }
             # Add new cc if any
 	    if ($add_cc && user_isloggedin())
 	      {
 		trackers_add_cc($item_id,
 				$group_id,
-				$add_cc,
-				$cc_comment, # 4
+				sane_post("add_cc"),
+				sane_post("cc_comment"), # 4
 				$changes);
 	      }
 
@@ -166,17 +162,17 @@ if ($group_id)
 		     (!user_isloggedin() && trackers_data_is_showed_on_add_nologin($oe_field_name))) 
 		  {
                     # cannot be a registered user
-		    if (validate_email($_REQUEST{$oe_field_name}))
+		    if (validate_email(sane_post("oe_field_name")))
 		      {
                         # must be different from the submitter field
 			$user=user_getid();
 			$submitter_email = db_result(db_query("SELECT email FROM user WHERE user_id=".$user),
 						     0, 'email');
-			if ($_REQUEST{$oe_field_name} != $submitter_email)
+			if (sane_post("oe_field_name") != $submitter_email)
 			  {
 			    trackers_add_cc($item_id,
 					    $group_id,
-					    $_REQUEST{$oe_field_name},
+					    sane_post("oe_field_name"),
 					    "Originator Email",
 					    $changes);
 			  }
@@ -288,11 +284,11 @@ if ($group_id)
 	    $address = "";
 	    $changed = trackers_data_handle_update($group_id,
 						   $item_id,
-						   $dependent_on_task,
-						   $dependent_on_bugs, # 4
-						   $dependent_on_support,
-						   $dependent_on_patch, # 6
-						   $canned_response,
+						   sane_post("dependent_on_task"),
+						   sane_post("dependent_on_bugs"), # 4
+						   sane_post("dependent_on_support"),
+						   sane_post("dependent_on_patch"), # 6
+						   sane_post("canned_response"),
 						   $vfl, # 8
 						   $changes,
 						   $address);
@@ -326,9 +322,9 @@ if ($group_id)
 		# it is irrelevant to the item itself
 		trackers_add_cc($item_id,
 				$group_id,
-				$add_cc,
-				$cc_comment, # 4
-				$changes);
+				sane_post("add_cc"),
+				sane_post("cc_comment"), # 4
+				sane_post("changes"));
 	      }
 
 	    # Update vote (will do the necessary checks itself)
@@ -338,7 +334,7 @@ if ($group_id)
 	      {
 		trackers_votes_update($item_id,
 				      $group_id,
-				      $new_vote);		      
+				      sane_post("new_vote"));		      
 	      }
 	    
 	    if ($changed)
@@ -362,8 +358,8 @@ if ($group_id)
 	      {
 		dbg("reassign item: reassign_change_project:$reassign_change_project, reassign_change_artifact:$reassign_change_artifact, ARTIFACT:".ARTIFACT);
 		trackers_data_reassign_item ($item_id,
-					     $reassign_change_project,
-					     $reassign_change_artifact);
+					     sane_post("reassign_change_project"),
+					     sane_post("reassign_change_artifact"));
 	      }
 	    
 	    form_clean($form_id);    
@@ -377,7 +373,7 @@ if ($group_id)
 	      }
 	    else
 	      {
-		unset($_POST, $_FILES, $form_id, $depends_search, $reassign_change_project_search, $add_cc, $input_file, $changed, $vfl, $details); 
+		unset($_POST, $_FILES, $form_id, $depends_search, $reassign_change_project_search, $add_cc, $input_file, $changed, $vfl, $details, $comment); 
 		$nocache = 1;
 		include '../include/trackers_run/mod.php';
 	      }
@@ -396,13 +392,13 @@ if ($group_id)
 	  { exit_error(_("Exiting")); }
 
         # Add a new comment if there is one
-	if ($details != '')
+	if ($comment != '')
 	  {
             # For none project members force the comment type to None (100)
-	    trackers_data_add_history('details',htmlspecialchars($details),'',$item_id,100);
+	    trackers_data_add_history('details',htmlspecialchars($comment),'',$item_id,100);
 
             # YPE fix to trigger notifications in case of non member
-	    $changes['details']['add'] = stripslashes($details);
+	    $changes['details']['add'] = stripslashes($comment);
 	    $changes['details']['type'] = 'None';
 	    $changed = true;
 
@@ -428,8 +424,8 @@ if ($group_id)
             # it is irrelevant to the item itself
 	    trackers_add_cc($item_id,
 			    $group_id,
-			    $add_cc,
-			    $cc_comment, # 4
+			    sane_post("add_cc"),
+			    sane_post("cc_comment"), # 4
 			    $changes);
 	  }
 	
@@ -444,7 +440,7 @@ if ($group_id)
                 # (that could harass developers)
 		trackers_votes_update($item_id,
 				      $group_id,
-				      $new_vote);	
+				      sane_post("new_vote"));	
 	      }
 	  }
 	if ($changed)
@@ -455,7 +451,7 @@ if ($group_id)
 		$address .= ", ";
 	      }
 	    $address .= $additional_address;
-	    trackers_mail_followup($item_id, $address,$changes);
+	    trackers_mail_followup($item_id, $address, $changes);
 	  }
 	    
 	form_clean($form_id);
@@ -470,7 +466,9 @@ if ($group_id)
 
 	if (member_check(0,$group_id, member_create_tracker_flag(ARTIFACT).'2'))
 	  {
-	    trackers_data_delete_file($group_id,$item_id,$item_file_id);
+	    trackers_data_delete_file($group_id,
+				      $item_id,
+				      sane_all("item_file_id"));
 
             # unset previous settings and return to the item
 	    unset($depends_search, $reassign_change_project_search, $add_cc, $input_file, $changed, $vfl, $details); 
@@ -486,7 +484,10 @@ if ($group_id)
     case 'delete_cc' :
       {
         #### Remove a person from the Cc: list of a bug
-	$changed = trackers_delete_cc($group_id,$item_id,$item_cc_id,$changes);
+	$changed = trackers_delete_cc($group_id,
+				      $item_id,
+				      sane_all("item_cc_id"),
+				      $changes);
 
 	# Irrevelant: no need to warn people that someone got retired from the
 	# cc list.
@@ -515,8 +516,8 @@ if ($group_id)
 
 	  $changed |= trackers_delete_dependancy($group_id,
 						$item_id,
-						$item_depends_on,
-						$item_depends_on_artifact,
+						sane_all("item_depends_on"),
+						sane_all("item_depends_on_artifact"),
                                                 $changes);
 
 	  if ($changed)
