@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: mod.php,v 1.48 2005/09/22 08:29:22 yeupou Exp $
+# $Id: mod.php 5187 2005-12-01 16:22:29Z yeupou $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2001-2002 (c) Laurent Julliard, CodeX Team, Xerox
@@ -24,6 +24,7 @@
 # along with the Savane project; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 
+
 # Need search functions.
 require_directory("search");
 
@@ -199,11 +200,19 @@ if (db_numrows($result) > 0)
 
              # If nocache is set, we were explicetely asked to rely only
              # on database content
+	     # If we rely on submitted by form content, due to magic_quotes,
+	     # we need to run both stripslashes and htmlspecialchars
 	      if (!$$field_name || $nocache)
 		{ $field_value = db_result($result,0,$field_name); }
 	      else
-		{ $field_value = htmlentities(stripslashes($$field_name)); }
-	      
+		{ $field_value = htmlspecialchars(stripslashes($$field_name)); }
+	      # On the cookbook, the recipe text must allow to see html
+	      # special chars as they were typed.
+	      if (ARTIFACT == "cookbook" && $field_name == 'details')
+		{
+		  $field_value = htmlspecialchars($field_value);
+		}
+
 	      list($sz,) = trackers_data_get_display_size($field_name);
 	      $label = trackers_field_label_display($field_name,$group_id,false,false);
 	      
@@ -212,17 +221,18 @@ if (db_numrows($result) > 0)
 		{ $item_assigned_to = trackers_field_display($field_name,$group_id,$field_value,false,false,true); 
 		}
 
-               # original submission field must be displayed read-only
+               # original submission field must be displayed read-only,
+	       # (unless we are on the cookbook)
                # assigned_to, status_id and priority too, for technicians
                # (if super_user, do nothing)
 	      if (!user_is_super_user())
 		{ $mbcheck = member_check(0,$group_id,member_create_tracker_flag(ARTIFACT).'1', 1); }
 
-	      if ($field_name =='details' ||
-		  $mbcheck && $field_name =='status_id' ||
-		  $mbcheck && $field_name =='assigned_to' ||
-		  $mbcheck && $field_name =='priority' ||
-		  $mbcheck && $field_name =='originator_email')
+	      if (($field_name =='details' && ARTIFACT != "cookbook") ||
+		  ($mbcheck && $field_name == 'status_id') ||
+		  ($mbcheck && $field_name == 'assigned_to') ||
+		  ($mbcheck && $field_name == 'priority') ||
+		  ($mbcheck && $field_name == 'originator_email'))
 		{
 		  dbg("field_name:$field_name is read-only, mbcheck_is_not_manager:$mbcheck_is_not_manager");
 		  $value = utils_make_links(trackers_field_display($field_name,$group_id,$field_value,false,false,true));
@@ -247,17 +257,11 @@ if (db_numrows($result) > 0)
 		   trackers_check_is_shown_to_submitter($field_name, $group_id, db_result($result,0,'submitted_by'))))
 		  
 		{
-		  $star = '<font class="warn"> *</font>';
+		  $star = '<span class="warn"> *</span>';
 		}
 
               # Fields colors
 	      unset($field_class, $row_class);
-	      if ($previous_form_bad_fields && array_key_exists($field_name, $previous_form_bad_fields))
-		{  
-                  # We highlight fields that were not properly/completely 
-		  # filled.
-		  $field_class = ' class="highlight"';
-		}
 	      if ($j % 2 && $field_name != 'details')
 		{
 		  # We keep the original submission with the default
@@ -267,12 +271,26 @@ if (db_numrows($result) > 0)
 		  # out of two, to keep the page light
 		  $row_class = ' class="'.utils_altrow($j+1).'"'; 
 		}
-		  
+		 
+	      # If we are working on the cookbook, present checkboxes to
+	      # defines context before the summary line;
+	      if (CONTEXT == 'cookbook' && $field_name == 'summary')
+		{
+		  cookbook_print_form();
+		}
+
+              # We highlight fields that were not properly/completely 
+	      # filled.
+	      if ($previous_form_bad_fields && array_key_exists($field_name, $previous_form_bad_fields))
+		{  
+		  $field_class = ' class="highlight"';
+		}
+
 	      if ($sz > $max_size)
 		{
 		  # Field getting one line for itself 
 
-                  # Each time change the background color
+                  # Each time prepare the change of the background color
 		  $j++;
 
 		  print "\n<tr".$row_class.">".
@@ -305,7 +323,7 @@ if (db_numrows($result) > 0)
     }
 
   print '</table>';
-  print '<p class="warn"><font class="smaller">* '._("Mandatory Fields").'</font></p>';
+  print '<p class="warn"><span class="smaller">* '._("Mandatory Fields").'</span></p>';
   print '<p>&nbsp;</p>';
 
 # ################################ Shortcuts
@@ -319,7 +337,7 @@ if (db_numrows($result) > 0)
     {
       print '&nbsp;&nbsp;- <a href="#votes">'._("Votes").'</a><br />';
     }
-  if (member_check(0,$group_id, member_create_tracker_flag(ARTIFACT).'3'))
+  if (member_check(0,$group_id, member_create_tracker_flag(ARTIFACT).'3') && ARTIFACT != "cookbook")
     {
       print '&nbsp;&nbsp;- <a href="#reassign">'._("Reassign this item").'</a><br />';
     }
@@ -332,22 +350,22 @@ if (db_numrows($result) > 0)
   print '<h3>'.html_anchor(_("Follow-up Comments"), 'comments').'</h3>';
   print '<p class="noprint">';
   printf (_("(Note: you can add pointers to others items by typing %s where %s is one of %s and %s the item id number.)"),
-	  "<font class=\"italic\">artifact #nnn</font>",
-	  "<font class=\"italic\">artifact</font>",
-	  "<font class=\"italic\">support, bug, task, patch</font>",
-	  "<font class=\"italic\">nnn</font>");
+	  "<span class=\"italic\">artifact #nnn</span>",
+	  "<span class=\"italic\">artifact</span>",
+	  "<span class=\"italic\">support, bug, task, recipe, patch, file</span>",
+	  "<span class=\"italic\">nnn</span>");
 
-  print '<p class="noprint"><font class="preinput"> '._("Add a New Comment:").'</font><br />
+  print '<p class="noprint"><span class="preinput"> '._("Add a New Comment:").'</span><br />
       &nbsp;&nbsp;&nbsp;';
-  print trackers_field_textarea('details',$details);
+  print trackers_field_textarea('comment',  htmlspecialchars(stripslashes($comment)));
   print '<p>';
 
-  print '<p class="noprint"><font class="preinput">';
-  print _("Comment Type:").'</font><br />&nbsp;&nbsp;&nbsp';
+  print '<p class="noprint"><span class="preinput">';
+  print _("Comment Type:").'</span><br />&nbsp;&nbsp;&nbsp';
   print trackers_field_box('comment_type_id',$comment_type_id,$group_id,'',true,'None');
 
 
-  print '<br /><font class="preinput">'._("Use a Canned Response:").'</font><br />&nbsp;&nbsp;&nbsp;';
+  print '<br /><span class="preinput">'._("Use a Canned Response:").'</span><br />&nbsp;&nbsp;&nbsp;';
 
   if ($canned_response == "!multiple!")
     {
@@ -366,7 +384,7 @@ if (db_numrows($result) > 0)
 	}
       else
 	{
-	  print '<font class="warn">'._("Strangely enough, there is no canned response available.").'</font>';
+	  print '<span class="warn">'._("Strangely enough, there is no canned response available.").'</span>';
 	}
 
     }
@@ -377,7 +395,7 @@ if (db_numrows($result) > 0)
       print '&nbsp;&nbsp;&nbsp;<a class="smaller" href="'.$GLOBALS['sys_home'].ARTIFACT.'/admin/field_values.php?group_id='.$group_id.'&create_canned=1">('._("Or define a new Canned Response").')</a>';
 
     }
-  print '<br /><font class="preinput">'._("Previous Comment Style:").'</font><br />&nbsp;&nbsp;&nbsp;';
+  print '<br /><span class="preinput">'._("Previous Comment Style:").'</span><br />&nbsp;&nbsp;&nbsp;';
   if ($quotation_style != "quoted") 
     {
       print '<input type="submit" name="change_quotation_style" value="'._("Quoted, ready to be copied/pasted into your new comment").'" />';
@@ -400,10 +418,10 @@ if (db_numrows($result) > 0)
 
   print '<h3>'.html_anchor(_("Attached Files"), "attached").'</h3>';
 
-  print '<p class="noprint"><font class="preinput"> '._("Attach File:").'</font><br />
+  print '<p class="noprint"><span class="preinput"> '._("Attach File:").'</span><br />
       &nbsp;&nbsp;&nbsp;<input type="file" name="input_file" size="40">
       <br />
-      <font class="preinput">'._("File Description:").'</font><br />
+      <span class="preinput">'._("File Description:").'</span><br />
       &nbsp;&nbsp;&nbsp;<input type="text" name="file_description" size="60" maxlength="255">
       </p><p>';
 
@@ -414,7 +432,7 @@ if (db_numrows($result) > 0)
 # ################################ Dependencies
 
   print '<h3>'.html_anchor(_("Dependencies"), "dependencies").'</h3>';
-  print '<p class="noprint"><font class="preinput">';
+  print '<p class="noprint"><span class="preinput">';
   if (!$depends_search)
     { print _("Search an item (to fill a dependancy against):"); }
   else
@@ -424,7 +442,7 @@ if (db_numrows($result) > 0)
       print _("New search, in case the previous one was not satisfactory (to fill a dependancy against):");
     }
 
-  print '</font><br />
+  print '</span><br />
       &nbsp;&nbsp;&nbsp;<input type="text" name="depends_search" size="40" maxlength="255"><br />';
 
 
@@ -437,7 +455,7 @@ if (db_numrows($result) > 0)
       unset($checked);
     }
 
-  print '<font class="preinput">'._("Of:").'</font><br />
+  print '<span class="preinput">'._("Of:").'</span><br />
 &nbsp;&nbsp;&nbsp;<select name="depends_search_only_artifact">'
     .'<option value="all">'._("any Trackers").'</option>';
 
@@ -467,9 +485,9 @@ if (db_numrows($result) > 0)
 # Search results, if we are already at step 2 of filling
   if ($depends_search)
     {
-      print '</p><p><font class="preinput">';
+      print '</p><p><span class="preinput">';
       printf (_("Please select a dependancy to add in the result of your search of '%s' in the database:"), $depends_search);
-      print '</font>';
+      print '</span>';
 
       unset($success);
 
@@ -520,9 +538,9 @@ if (db_numrows($result) > 0)
 	}
       if (!$success)
 	{
-	  print '<br /><font class="warn">';
+	  print '<br /><span class="warn">';
 	  print _("None found. Please note that only search words of more than three characters are valid.");
-	  print '</font>';
+	  print '</span>';
 	}
 
     }
@@ -545,11 +563,11 @@ if (db_numrows($result) > 0)
   print '<p class="noprint">';
   printf (_("(Note: for %s users, you can use their login name rather than their email addresses.)"), $GLOBALS['sys_name']);
 
-  print '</p><p class="noprint"><font class="preinput">'
-    ._("Add an email address that should receive carbon copies of updates of this item:").'</font><br />&nbsp;&nbsp;&nbsp;<input type="text" name="add_cc" size="40" value="'.$add_cc.'">&nbsp;&nbsp;&nbsp;
+  print '</p><p class="noprint"><span class="preinput">'
+    ._("Add an email address that should receive carbon copies of updates of this item:").'</span><br />&nbsp;&nbsp;&nbsp;<input type="text" name="add_cc" size="40" value="'.$add_cc.'">&nbsp;&nbsp;&nbsp;
         <br />
-        <font class="preinput">'
-    ._("Comment:").'</font><br />&nbsp;&nbsp;&nbsp;<input type="text" name="cc_comment" size="40" maxlength="255" value="'.$cc_comment.'" />';
+        <span class="preinput">'
+    ._("Comment:").'</span><br />&nbsp;&nbsp;&nbsp;<input type="text" name="cc_comment" size="40" maxlength="255" value="'.$cc_comment.'" />';
   print '<p></p>';
   show_item_cc_list($item_id, $group_id);
 
@@ -572,18 +590,19 @@ if (db_numrows($result) > 0)
 # Show how many vote he already gave and allows to remove or give more
 # votes.
 # The number of remaining points must be 100 - others votes
-      print '<font class="preinput">'._("Your vote:").'</font><br />&nbsp;&nbsp;&nbsp;<input type="text" name="new_vote" size="3" maxlength="3" value="'.$new_vote.'" /> '.sprintf(ngettext("/ %s remaining vote", "/ %s remaining votes", $votes_remaining), $votes_remaining);
+      print '<span class="preinput">'._("Your vote:").'</span><br />&nbsp;&nbsp;&nbsp;<input type="text" name="new_vote" size="3" maxlength="3" value="'.$new_vote.'" /> '.sprintf(ngettext("/ %s remaining vote", "/ %s remaining votes", $votes_remaining), $votes_remaining);
       print '</p>';
       print '<p>&nbsp;</p>';
     }
 
 # ################################ Reassign an item, if manager of the tracker
-  if (member_check(0,$group_id, member_create_tracker_flag(ARTIFACT).'3'))
+# Not possible on the cookbook manager, cookbook entries are too specific
+  if (member_check(0,$group_id, member_create_tracker_flag(ARTIFACT).'3') && ARTIFACT != "cookbook")
     {
       print '<h3 class="noprint">'.html_anchor(_("Reassign this item"), "reassign").'</h3>';
 
-      print '<p class="noprint"><font class="preinput">'
-	._("Move to the:").'</font><br />&nbsp;&nbsp;&nbsp;';
+      print '<p class="noprint"><span class="preinput">'
+	._("Move to the:").'</span><br />&nbsp;&nbsp;&nbsp;';
 
       function specific_reassign_artifact ($art, $content)
 	{
@@ -601,7 +620,7 @@ if (db_numrows($result) > 0)
       print '</select>';
 
       print '<br /><br />
-        <font class="preinput">';
+        <span class="preinput">';
 
       if (!$reassign_change_project_search)
 	{  print _("Move to the project:"); }
@@ -612,7 +631,7 @@ if (db_numrows($result) > 0)
 	  print _("New search, in case the previous one was not satisfactory (to reassign the item to another project):");
 	}
 
-      print '</font><br />&nbsp;&nbsp;&nbsp;<input type="text" name="reassign_change_project_search" size="40" maxlength="255">';
+      print '</span><br />&nbsp;&nbsp;&nbsp;<input type="text" name="reassign_change_project_search" size="40" maxlength="255">';
       if (!$reassign_change_project_search)
 	{
 	  print ' <input type="submit" name="submit" value="'._("Search").'">';
@@ -628,9 +647,9 @@ if (db_numrows($result) > 0)
 # Search results, if we are already at step 2 of filling
       if ($reassign_change_project_search)
 	{
-	  print '</p><p><font class="preinput">';
+	  print '</p><p><span class="preinput">';
 	  printf (_("To which project this bug should be reassigned to? This is the result of your search of '%s' in the database:"), $reassign_change_project_search);
-	  print '</font>';
+	  print '</span>';
 
 # Print a null-option, someone may change his mine without having
 # to use the back button of his browser.
@@ -656,9 +675,9 @@ if (db_numrows($result) > 0)
 
 	  if (!$success)
 	    {
-	      print '<br /><font class="warn">';
+	      print '<br /><span class="warn">';
 	      print _("None found. Please note that only search words of more than three characters are valid.");
-	      print '</font>';
+	      print '</span>';
 	    }
 
 	}
