@@ -2,13 +2,13 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: user_home.php,v 1.40 2005/09/23 14:42:56 toddy Exp $
+# $Id: user_home.php 5187 2005-12-01 16:22:29Z yeupou $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2000-2001 (c) Free Software Foundation
 #
 #  Copyright 2003-2004 (c) Mathieu Roy <yeupou--at--gnu.org>
-# 
+#
 # The Savane project is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
 # as published by the Free Software Foundation; either version 2
@@ -23,17 +23,18 @@
 # along with the Savane project; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 
-site_header(array('title'=>_("User Profile"),'toptab'=>'people'));
+site_header(array('title'=>_("User Profile"),'context'=>'people'));
 
- 
 # Assumes $res_user result handle is present
 
-if (!$res_user || db_numrows($res_user) < 1) 
+if (!$res_user || db_numrows($res_user) < 1)
 {
   exit_error('No Such User','No Such User');
 }
 
-# permit to the user to specify something 
+$detailed = sane_post("detailed");
+
+# permit to the user to specify something
 $form_opening = '<form action="'. $PHP_SELF .'" method="post">';
 if ($detailed)
 { $checked = " selected"; }
@@ -54,8 +55,8 @@ print html_splitpage(1);
 if ($detailed)
 {
   $artifacts = array("support", "bugs", "task", "patch");
-  
-  function specific_print_items ($criterion, $user_id) 
+
+  function specific_print_items ($criterion, $user_id)
     {
       # Print full info for the still opened items, just list the remaining.
       $k = 1;
@@ -67,9 +68,9 @@ if ($detailed)
 	     ' WHERE  '.$criterion.'='.$user_id.' ORDER BY date DESC';
 	  $result = db_query($sql);
 	  $rows = db_numrows($result);
-	  if ($result && $rows > 0) 
+	  if ($result && $rows > 0)
 	    {
-	      for ($j=0; $j<$rows; $j++) 
+	      for ($j=0; $j<$rows; $j++)
 		{
 		  # Private items are simply ignored
 		  if (db_result($result,$j,'privacy') != 2)
@@ -84,7 +85,7 @@ if ($detailed)
 			  print '</td></tr><tr><td colspan="2" class="'.utils_get_alt_row_color($k).'">'."\n\n";
 			}
 		      else
-			{ 
+			{
 			  $closed .= '<a href="'.$GLOBALS['sys_home'].$artifact.'/?func=detailitem&amp;item_id='.db_result($result,$j,'bug_id').'">';
 			  $closed .= '['.$artifact.' #'.db_result($result,$j,'bug_id').']';
 			  $closed .= '</a>, ';
@@ -92,28 +93,28 @@ if ($detailed)
 		      $exists = 1;
 		    }
 		}
-	    }            
+	    }
 	}
       if ($closed)
 	{ echo _("Closed:").' '.substr($closed,0,-2).'.'; }
-      
+
       if (!$exists)
 	{ echo '<font class="warn">'._("None found.").'</font>'; }
-      
+
     }
 
   $HTML->box1_top(sprintf(_("Items submitted by %s"),db_result($res_user,0,'realname')));
   # FIXME: News item are missing
-  specific_print_items("submitted_by", db_result($res_user,0,'user_id'));  
+  specific_print_items("submitted_by", db_result($res_user,0,'user_id'));
   $HTML->box1_bottom();
-      
+
   print '<br /><br />';
 
   $HTML->box1_top(sprintf(_("Items assigned to %s"),db_result($res_user,0,'realname')));
   # FIXME: News item are missing
   specific_print_items("assigned_to", db_result($res_user,0,'user_id'));
   $HTML->box1_bottom();
-  
+
 
 
 print html_splitpage(2);
@@ -177,9 +178,9 @@ print '</p>
 </tr>
 ';
 
-if (db_result($res_user,0,'gpg_key') != "") {	
+if (db_result($res_user,0,'gpg_key') != "") {
 	print '<tr valign="top"><td></td><td>';
-	print	'<a href="'.$GLOBALS['sys_home'].'people/viewgpg.php?user_id='.db_result($res_user,0,'user_id').'"><b>'._("View GPG Key").'</b></a>';
+	print	'<a href="'.$GLOBALS['sys_home'].'people/viewgpg.php?user_id='.db_result($res_user,0,'user_id').'"><b>'._("Download GPG Key").'</b></a>';
 	print '</td></tr>';
 }
 
@@ -187,7 +188,7 @@ print '</table>';
 
 $HTML->box1_bottom();
 
-if (!$detailed) 
+if (!$detailed)
 {
   print html_splitpage(2);
 
@@ -227,18 +228,22 @@ $j = 1;
 unset($content);
 for ($i=0; $i<$rows; $i++)
 {
-  $content .= '<li class="'.utils_get_alt_row_color($j).'">';  
+  $content .= '<li class="'.utils_get_alt_row_color($j).'">';
   $content .= '<a href="'.$GLOBALS['sys_home'].'projects/'. db_result($result,$i,'unix_group_name') .'/">'.db_result($result,$i,'group_name').'</a><br />';
-  if (db_result($result,$i,'date'))
+  $date_joined = db_result($result, $i, 'date');
+  if ($date_joined)
     {
-# If the group history is flawed (site install problem), the
-# date may be unavailable
-      $content .= '<font class="smaller">'.sprintf(_("Member since %s"), strftime('%B %Y',db_result($result,$i,'date'))).'</font>';
+      # If the group history is flawed (site install problem), the
+      # date may be unavailable
+      $content .= '<font class="smaller">'.
+        sprintf(_("Member since %s"),
+        format_date('', $date_joined)).
+        '</font>';
     }
   $content .= '</li>';
-      $exists=1;
-      $j++;
-    }
+  $exists=1;
+  $j++;
+}
 
 if (!$exists)
 {
@@ -260,9 +265,9 @@ if (user_isloggedin()) {
 
 } else {
 	echo '<h3>'._("You Could Send a Message if you were logged in").'.</h3>';
-  
+
 }
- 
+
 
 
 
