@@ -2,12 +2,13 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: utils.php,v 1.77 2005/09/13 13:30:34 yeupou Exp $
+# $Id: utils.php 5187 2005-12-01 16:22:29Z yeupou $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2000-2003 (c) Free Software Foundation
 #
 #  Copyright 2002-2005 (c) Mathieu Roy <yeupou--gnu.org>,
+#                          Tobias Toedter <t.toedter--gmx.net>
 #
 # The Savane project is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -23,9 +24,10 @@
 # along with the Savane project; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 
-
-# Many functions in this file do not set sys_debug_where, they are too
-# low level ones, they are not the functions that can call dbg().
+function utils_safeinput ($string)
+{
+  return safeinput($string);
+}
 
 
 # This function permit including site specific content with ease
@@ -81,7 +83,7 @@ function utils_link ($url, $title, $defaultclass=0, $available=1, $help=0)
 }
 
 # Found out if a string is pure ASCII or not
-function utils_is_ascii ($string) 
+function utils_is_ascii ($string)
 {
   return preg_match('%^(?: [\x09\x0A\x0D\x20-\x7E] )*$%xs', $string);
 }
@@ -104,28 +106,81 @@ function utils_cutstring ($string, $lenght=35)
   return $string;
 }
 
-# This function returns a string of the date $value with the format $format
-# and if this date is not set, return the default value $default_value
-function format_date ($format,$value,$default_value = '-')
+##
+# Returns a formatted date for a unix timestamp with the given format
+#
+# Alias of utils_format_date() with inverted parameters (look out!)
+#
+function format_date($format="default", $timestamp, $default_value='-')
 {
-  if ($value == 0)
-    {
-      return $default_value;
-
-    }
-  else
-    {
-      if ($format)
-	{
-	  return date($format,$value);
-	}
-      else
-	{
-	  return strftime('%a %x '._("at").' %R',$value);
-	}
-    }
+  return utils_format_date($timestamp, $format);
 }
 
+##
+# Returns a formatted date for a unix timestamp
+#
+# The given unix timestamp will be formatted according to
+# the $format parameter. Note that this parameter is not one
+# of the format strings supported by functions such as
+# strftime(), but a description instead.
+#
+# Currently, you can use the following values for $format:
+#   - default => localized Fri 18 November 2005 at 18:51
+#   - short => localized 18/11/2005, 18:51
+#   - minimal => localized 18/11/2005
+#
+# @see utils_date_to_unixtime()
+function utils_format_date($timestamp, $format="default")
+{
+  global $sys_datefmt;
+  if ($timestamp == 0)
+    {
+      return '-';
+    }
+
+  # The installation configured a specific date format. This is not nice
+  # this will prevent locales from being used
+  if ($sys_datefmt)
+    {
+      return strftime($sys_datefmt, $timestamp);
+    }
+
+  ## Go at task #2614 to discuss about this
+  # Used by default
+  switch ($format)
+    {
+    case 'short':
+      {
+	# To be used in tables, nowhere else
+	return strftime('%a %x, %R', $timestamp);
+      }
+    case 'minimal':
+      {
+        # To be used where place is really lacking, like in feature boxes.
+        # (Nowhere else, it is too uninformative)
+	return strftime('%x', $timestamp);
+      }
+    default:
+      {
+        # Used by default
+	# Mention timezone to non-logged in users or in printer mode.
+	# Logged-in users have this as account setting, so we can assume they
+	# now and dont want time wasted by that
+	if (user_isloggedin() && !defined(PRINTER))
+	  {
+	    return strftime('%A %x '._("at").' %R', $timestamp);
+	  }
+	else
+	  {
+	    return strftime('%A %x '._("at").' %R %Z', $timestamp);
+	  }
+      }
+    }
+
+  return false;
+}
+
+
 # Convert a date as used in the bug tracking system and other services (YYYY-MM-DD)
 # into a Unix time
 # Returns a list with two values: the unix time and a boolean saying whether the conversion
@@ -376,9 +431,15 @@ function utils_line_wrap ($text, $wrap = 78, $break = "\n")
   return implode($break, $result);
 }
 
-function utils_make_links($data='',$group_id = 0)
+function utils_make_links($data='', $deprecated=0)
 {
-  # group_id is a deprecated useless parameter.
+  # Group_id may be necessary for recipe #nnn links
+  global $group_id;
+
+  if ($group_id)
+    {
+      $comingfrom = "&amp;comingfrom=$group_id";
+    }
 
   if (empty($data))
     { return $data; }
@@ -389,7 +450,7 @@ function utils_make_links($data='',$group_id = 0)
       # 1 and 2 could maybe be replaced by a better regexp, as they may in
       # some very rare case, break content. But we havent found such case.
       # Feel free to propose better regexp.
-      
+
       # 1. Don't mess with HTML links already there by escaping
       # the protocol separator with ":##"
       $line = eregi_replace("(<a href=\"[a-z]+)://([^<[:space:]]+)://([^<[:space:]]+)</a>", '\1:##\2:##\3</a>', $line);
@@ -435,7 +496,12 @@ function utils_make_links($data='',$group_id = 0)
       $line = eregi_replace("(bugs|bug)[ ]?#([0-9]+)", '<a href="'.$GLOBALS['sys_home']."bugs/?func=detailitem&amp;item_id=\\2\" class=\"italic\">bug&nbsp;#\\2</a>", $line);
       $line = eregi_replace("(support|sr)[ ]?#([0-9]+)", '<a href="'.$GLOBALS['sys_home']."support/?func=detailitem&amp;item_id=\\2\" class=\"italic\">sr&nbsp;#\\2</a>", $line);
       $line = eregi_replace("task[ ]?#([0-9]+)", '<a href="'.$GLOBALS['sys_home']."task/?func=detailitem&amp;item_id=\\1\" class=\"italic\">task&nbsp;#\\1</a>", $line);
+      $line = eregi_replace("(recipe|rcp)[ ]?#([0-9]+)", '<a href="'.$GLOBALS['sys_home']."cookbook/?func=detailitem$comingfrom&amp;item_id=\\2\" class=\"italic\">recipe&nbsp;#\\2</a>", $line);
       $line = eregi_replace("patch[ ]?#([0-9]+)", '<a href="'.$GLOBALS['sys_home']."patch/?func=detailitem&amp;item_id=\\1\" class=\"italic\">patch&nbsp;#\\1</a>", $line);
+      # In this case, we make the link pointing to support, it wont matter,
+      # the download page is in every tracker and does not check if the tracker
+      # is actually used
+      $line = eregi_replace("file[ ]?#([0-9]+)", '<a href="'.$GLOBALS['sys_home']."support/download.php?file_id=\\1\" class=\"italic\">file&nbsp;#\\1</a>", $line);
       $line = eregi_replace("comment[ ]?#([0-9]+)", '<a href="#comment\\1">comment&nbsp;#\\1</a>', $line);
 
       $lines[$key] = $line;
@@ -528,6 +594,8 @@ function utils_get_tracker_icon ($tracker)
     { return "bug"; }
   if ($tracker == "support")
     { return "help"; }
+  if ($tracker == "cookbook")
+    { return "man"; }
   return $tracker;
 }
 
@@ -537,7 +605,9 @@ function utils_get_tracker_prefix ($tracker)
     { return "bug"; }
   if ($tracker == "support")
     { return "sr"; }
-  return $tracker; 
+  if ($tracker == "cookbook")
+    { return "recipe"; }
+  return $tracker;
 }
 
 
@@ -945,8 +1015,20 @@ function feedback ($msg, $error=0)
 }
 
 # add feedback information
-function fb ($msg, $error=0)
+function fb ($msg, $error=0, $enablehtml=0)
 {
+  # If ware in enablehtml mode, it means that the feedback may contain real
+  # html.
+  # It means that we need to remove previous feedback to avoid malicious usage
+  # of the feedback form.
+  # This should be used on rare occasions.
+  # We will also set feedback_html.
+  if ($enablehtml)
+    {
+      unset($GLOBALS['feedback'], $GLOBALS['ffeedback']);
+      $GLOBALS['feedback_html'] = 1;
+    }
+
   # Increment feedback count
   $GLOBALS['feedback_count']++;
 
