@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: index.php,v 1.76 2005/06/30 17:19:36 toddy Exp $
+# $Id: index.php 5187 2005-12-01 16:22:29Z yeupou $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2000-2003 (c) Free Software Foundation
@@ -297,7 +297,8 @@ if ($group_id && user_ismember($group_id,'A'))
   if ($add_list)
     {
 
-      site_project_header(array('title'=>_("Add a Mailing List"),'group'=>$group_id,'toptab'=>'amail'));
+      site_project_header(array('title'=>_("Add a Mailing List"),'group'=>$group_id,'context'=>'amail'));
+
 
       utils_get_content("mail/about_list_creation");
 
@@ -351,7 +352,8 @@ if ($group_id && user_ismember($group_id,'A'))
     {
       # Show the form to modify lists status
 
-    site_project_header(array('title'=>_("Update Mailing List"),'group'=>$group_id,'toptab'=>'amail'));
+    site_project_header(array('title'=>_("Update Mailing List"),'group'=>$group_id,'context'=>'amail'));
+
 
     $sql="SELECT list_name,group_list_id,is_public,description ".
        "FROM mail_group_list ".
@@ -426,7 +428,8 @@ if ($group_id && user_ismember($group_id,'A'))
       # Note: I did not checked that part of the code, that should remain
       # unchanged. Hope it will still work.
       # yeupou@gnu.org 2003-09-24
-      site_project_header(array('title'=>_("Migrate Mailing Lists"),'group'=>$group_id,'toptab'=>'amail'));
+      site_project_header(array('title'=>_("Migrate Mailing Lists"),'group'=>$group_id,'context'=>'amail'));
+
 
       if ($isgnu == false)
 	{
@@ -558,19 +561,20 @@ if ($group_id && user_ismember($group_id,'A'))
 			Show main page for choosing
 			either moderotor or delete
       ***********************************************************/
-    site_project_header(array('group'=>$group_id,'toptab'=>'amail'));
+    site_project_header(array('group'=>$group_id,'context'=>'amail'));
+
 
     print '
-<h3><A HREF="'.$PHP_SELF.'?group='.$group_name.'&add_list=1">'._("Add Mailing List").'</A></h3><DD>'._("You can create mailing lists for your project using the web interface.").'</DD>
+<A HREF="'.$PHP_SELF.'?group='.$group_name.'&add_list=1">'._("Add Mailing List").'</A><p class="text">'._("You can create mailing lists for your project using the web interface.").'</p>
 
-<h3><A HREF="'.$PHP_SELF.'?group_id='.$group_id.'&change_status=1">'._("Administrate/Update Lists").'</A></h3><DD>'._("Update information on existing mailing lists and change their policy.").'</DD>
+<A HREF="'.$PHP_SELF.'?group_id='.$group_id.'&change_status=1">'._("Administrate/Update Lists").'</A><p class="text">'._("Update information on existing mailing lists and change their policy.").'</p>
 			';
 
     if ($isgnu == true)
       {
 	print '
-<h3><A HREF="'.$PHP_SELF.'?group_id='.$group_id.'&migrate=1">Attach  a mailing list</A></h3>
-<DD>If a mailing list already exists for the '.group_getunixname($group_id).' project but is not <a href=/mail/?group_id='.$group_id.'>listed</a>, you can fix this. By telling Savannah that a mailing list that <a href=http://mail.gnu.org/mailman/listinfo>shows on mail.gnu.org</a> is indeed related to the '.group_getunixname($group_id).' project, you make it easier for contributors and users to find it. Note that this step is not necessary if you create a mailing list using Savannah: it will be done automatically. But it is necessary if the mailing list existed before the project was created on Savannah. </DD>
+<A HREF="'.$PHP_SELF.'?group_id='.$group_id.'&migrate=1">Attach  a mailing list</A>
+<p>If a mailing list already exists for the '.group_getunixname($group_id).' project but is not <a href=/mail/?group_id='.$group_id.'>listed</a>, you can fix this. By telling Savannah that a mailing list that <a href=http://mail.gnu.org/mailman/listinfo>shows on mail.gnu.org</a> is indeed related to the '.group_getunixname($group_id).' project, you make it easier for contributors and users to find it. Note that this step is not necessary if you create a mailing list using Savannah: it will be done automatically. But it is necessary if the mailing list existed before the project was created on Savannah. </p>
 	';
       }
     site_project_footer(array());
