@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: index.php,v 1.48 2005/06/30 17:19:36 toddy Exp $
+# $Id: index.php 5187 2005-12-01 16:22:29Z yeupou $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2000-2003 (c) Free Software Foundation
@@ -32,7 +32,8 @@ if ($group_id)
 
   exit_test_usesmail($group_id);
 
-  site_project_header(array('group'=>$group_id, 'toptab'=>'mail'));
+  site_project_header(array('group'=>$group_id, 'context'=>'mail'));
+
 
   
   if (user_isloggedin() && user_ismember($group_id)) 
