@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: groups.php,v 1.24 2005/09/19 11:21:01 yeupou Exp $
+# $Id: groups.php 5187 2005-12-01 16:22:29Z yeupou $
 #
 #  Copyright 2003-2005 (c) Frederik Orellana <frederik.orellana--cern.ch>
 #                          Mathieu Roy <yeupou--gnu.org>
@@ -26,13 +26,150 @@ require "../include/pre.php";
 require_directory("search");
 require_directory("trackers");
 
-# ###### get global user and group vars
+# Make this page register global off compliant
+register_globals_off();
 
+# Obtain general user info
 $res_user = db_query("SELECT * FROM user WHERE user_id=" . user_getid());
 $row_user = db_fetch_array($res_user);
-$sys_pending_user_permissions = $GLOBALS['sys_pending_user_permissions'];
-$register_error=0;
 
+# Obtain approval_user_gen_email() for site specific content
+utils_get_content("my/request_for_inclusion");
+
+
+###################################################################
+## Updates
+
+# Watchee add
+$func = sane_all("func");
+if ($func)
+{
+  $watchee_id = sane_all("watchee_id");
+  $group_id = sane_all("group_id");
+
+  if ($func == "delwatchee")
+    {
+# Stop watching another user
+      $result_upd = trackers_data_delete_watchees(user_getid(),$watchee_id,$group_id);
+      if (!$result_upd)
+	{
+	  fb(_("Unable to remove user from the watched users list, probably a broken URL"));
+	}
+
+    }
+
+  if ($func == "addwatchee")
+    {
+# Stop watching another user
+      $result_upd = trackers_data_add_watchees(user_getid(),$watchee_id,$group_id);
+      if (!$result_upd)
+	{
+	  fb(_("Unable to add user in the watched users list, probably a broken URL"));
+	}
+
+    }
+}
+
+
+
+# ###### function send_pending_user_email($group_id, $user_id, $user_message)
+# ###### sends an email to group admins when a user joins group
+
+function send_pending_user_email($group_id, $user_id, $user_message)
+{
+
+  $res_grp = db_query("SELECT * FROM groups WHERE group_id='$group_id'");
+
+  if (db_numrows($res_grp) < 1)
+    {
+      return 0;
+    }
+
+  $row_grp = db_fetch_array($res_grp);
+
+  $res_admins = db_query("SELECT user.user_name FROM user,user_group WHERE "
+			 . "user.user_id=user_group.user_id AND user_group.group_id='$group_id' AND "
+			 . "user_group.admin_flags='A'");
+
+  if (db_numrows($res_admins) < 1)
+    {
+      return 0;
+    }
+
+  # send one email per admin, in one command line coma separated
+  $admin_list = '';
+  while ($row_admins = db_fetch_array($res_admins))
+    {
+      $admin_list .= ($admin_list ? ',':'').$row_admins['user_name'];
+    }
+
+  $message = approval_user_gen_email($row_grp['group_name'],
+				     $row_grp['unix_group_name'],
+				     $group_id,
+				     user_getname($user_id),
+				     user_getrealname($user_id),
+				     user_getemail($user_id),
+				     $user_message);
+
+
+  sendmail_mail(user_getname(),
+		$admin_list,
+		sprintf(_("Membership request for group %s"), $row_grp['group_name']),
+		$message,
+		$row_grp['unix_group_name'],
+		"usermanagement");
+}
+
+# Request for inclusion
+if (sane_post("update"))
+{
+  $result_upd = db_query("SELECT group_id FROM groups WHERE status='A' AND
+            is_public='1' ORDER BY group_id");
+  $form_id = sane_post("form_id");
+
+  # Check for duplicates
+  if (!form_check($form_id))
+    { return 0; }
+  unset($form_cleaned_already);
+  
+  while ($val = db_fetch_array($result_upd))
+    {
+      if(sane_post("form_groups_$val[group_id]"))
+	{
+          # If not in group, add user with admin_flag "P"
+          # (not very sensible, but this way we avoid changing
+          # the table layout)
+	  if(!member_check_pending($row_user[user_id], $val[group_id]))
+	    {
+	      if(!sane_post("form_message"))
+		{
+		  fb(_("Error: When joining you must provide a message for the administrator, a short explanation of why you want to join this/these project(s)."), 1);
+		}
+	      else
+		{
+		  if(member_add($row_user[user_id], $val[group_id], 'P'))
+		    {
+		      send_pending_user_email($val[group_id], $row_user[user_id], $GLOBALS["form_message"]);
+		      if (!$form_cleaned_already)
+			{
+			  form_clean($form_id);
+			  $form_cleaned_already = 1;
+			}
+		    }
+		}
+	    }
+	  else
+	    {
+	      fb(_("Request for inclusion already registered"),1);
+	    }
+	}
+    }
+}
+
+
+
+
+# ###### get global user and group vars
 
 $sql = "SELECT groups.group_name,"
 . "groups.group_id,"
@@ -74,7 +211,7 @@ if ($rows_without_history != $rows)
 {
   # If number of rows differ, assume that history is flawed. Print a
   # feedback incitating to fix the installation and override flawed result
-  # 
+  #
   # The following update script was maybe forgot:
   # update/1.0.6/update_group_history.pl
   fb(_("Groups history appears to be flawed. This is a site installation problem. Please report the incident to administrators, asking them to get in touch with their Savane supplier."), 1);
@@ -83,153 +220,12 @@ if ($rows_without_history != $rows)
 }
 
 
-
-# ###### function send_pending_user_email($group_id, $user_id, $user_message)
-# ###### sends an email to group admins when a user joins group
-
-function send_pending_user_email($group_id, $user_id, $user_message)
-{
-	$GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':send_pending_user_email($group_id, $user_id, $user_message) ';
-
-  $res_grp = db_query("SELECT * FROM groups WHERE group_id='$group_id'");
-
-  if (db_numrows($res_grp) < 1)
-    {
-      return 0;
-    }
-
-  $row_grp = db_fetch_array($res_grp);
-
-  $res_admins = db_query("SELECT user.user_name FROM user,user_group WHERE "
-			 . "user.user_id=user_group.user_id AND user_group.group_id='$group_id' AND "
-			 . "user_group.admin_flags='A'");
-
-  if (db_numrows($res_admins) < 1)
-    {
-      return 0;
-    }
-
-  # send one email per admin, in one command line coma separated
-  $admin_list = '';
-  while ($row_admins = db_fetch_array($res_admins))
-    {
-      $admin_list .= ($admin_list ? ',':'').$row_admins['user_name'];
-    }
-
-  $message = approval_user_gen_email($row_grp['group_name'],
-				     $row_grp['unix_group_name'],
-				     $group_id,
-				     user_getname($user_id),
-				     user_getrealname($user_id),
-				     user_getemail($user_id),
-				     $user_message);
-
-  sendmail_mail(user_getname(),
-		$admin_list,
-		sprintf(_("Membership request for group %s"), $row_grp['group_name']),
-		$message,
-		$row_grp['unix_group_name'],
-		"usermanagement");
-}
-
-
-# ###### function update_tbl()
-# ###### updates tables if a post
-
-function update_tbl()
-{
-  $GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':update_tbl()	';
-  $ret_val = 1;
-
-  global $register_error;
-  global $row_user;
-  global $sys_pending_user_permissions;
-  global $form_id;
-
-  utils_get_content("my/request_for_inclusion");
-
-  $result_upd = db_query("SELECT group_id FROM groups WHERE status='A' AND
-            is_public='1' ORDER BY group_id");
-
-  if ($GLOBALS["update"])
-    {
-
-      # Check for duplicates
-      if (!form_check($form_id))
-	{ return 0; }
-      unset($form_cleaned_already);
-
-      while ($val = db_fetch_array($result_upd))
-	{
-	  if($GLOBALS["form_groups_$val[group_id]"])
-	    {
-               # If not in group, add user with admin_flag "P"
-               # (not very sensible, but this way we avoid changing
-	       # the table layout)
-	      if(!member_check_pending($row_user[user_id], $val[group_id]))
-		{
-		  if(!$GLOBALS["form_message"])
-		    {
-		      fb(_("Error: When joining you must provide a message for the administrator, a short explanation of why you want to join this/these project(s)."), 1);
-		      $ret_val = 0;
-		    }
-		  else
-		    {
-		      if(member_add($row_user[user_id], $val[group_id], 'P'))
-		      {
-			send_pending_user_email($val[group_id], $row_user[user_id], $GLOBALS["form_message"]);
-			if (!$form_cleaned_already)
-			  {
-			    form_clean($form_id);
-			    $form_cleaned_already = 1;
-			  }
-		      }
-		    }
-		}
-	      else
-		{
-		  fb(_("Request for inclusion already registered"),1);
-		}
-	    }
-	}
-      return $ret_val;
-    }
-  return 0;
-}
-
-# ###### first check if post, update requests
-
-update_tbl();
-
-# Some action to be done ?
-if ($func)
-{
-  if ($func == "delwatchee")
-    {
-# Stop watching another user
-      $result_upd = trackers_data_delete_watchees(user_getid(),$watchee_id,$group_id);
-      if (!$result_upd)
-	{
-	  fb(_("Unable to remove user from the watched users list, probably a broken URL"));
-	}
-
-    }
-
-  if ($func == "addwatchee")
-    {
-# Stop watching another user
-      $result_upd = trackers_data_add_watchees(user_getid(),$watchee_id,$group_id);
-      if (!$result_upd)
-	{
-	  fb(_("Unable to add user in the watched users list, probably a broken URL"));
-	}
-
-    }
-}
-
+###################################################################
+# Start HTML
 
 # page header
-site_user_header(array('toptab'=>'mygroups'));
+site_user_header(array('context'=>'mygroups'));
+
 
 # we get site-specific content
 utils_get_content("my/groups");
@@ -315,7 +311,7 @@ print '
 
 </div><!-- end boxitem -->';
 
-
+$words = sane_all("words");
 if ($words)
 {
   # Avoid to big search by asking for more than 3 characters.
@@ -333,7 +329,7 @@ if ($words)
 
   if (db_numrows($result_search) < 1)
     {
-      print '<br /><font class="warn">'._("None found. Please note that only search words of more than three characters are valid.").'</font><br />';
+      print '<br /><span class="warn">'._("None found. Please note that only search words of more than three characters are valid.").'</span><br />';
     }
   else
     {
@@ -402,11 +398,15 @@ else
 	   '<img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/trash.png" alt="'._("Quit this project?").'" /></a><br /></span>';
 
 	  $content .= '<a href="'.$GLOBALS['sys_home'].'projects/'. db_result($result,$i,'unix_group_name') .'/">'.db_result($result,$i,'group_name').'</a><br />';
-	  if (db_result($result,$i,'date'))
+	  $date_joined = db_result($result, $i, 'date');
+	  if ($date_joined)
 	    {
 	      # If the group history is flawed (site install problem), the
 	      # date may be unavailable
-	      $content .= '<font class="smaller">'.sprintf(_("Member since %s"), strftime('%B %Y',db_result($result,$i,'date'))).'</font>';
+	      $content .= '<font class="smaller">'.
+	        sprintf(_("Member since %s"),
+	        format_date('', $date_joined)).
+	        '</font>';
 	    }
 	  $content .= '</li>';
 	  $exists=1;
@@ -445,11 +445,15 @@ else
 	   '<img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/trash.png" alt="'._("Quit this project?").'" /></a></span>';
 
 	  $content .= '<a href="'.$GLOBALS['sys_home'].'projects/'. db_result($result,$i,'unix_group_name') .'/">'.db_result($result,$i,'group_name').'</a><br />';
-	  if (db_result($result,$i,'date'))
+	  $date_joined = db_result($result, $i, 'date');
+	  if ($date_joined)
 	    {
 	      # If the group history is flawed (site install problem), the
 	      # date may be unavailable
-	      $content .= '<font class="smaller">'.sprintf(_("Member since %s"), strftime('%B %Y',db_result($result,$i,'date'))).'</font>';
+	      $content .= '<font class="smaller">'.
+	        sprintf(_("Member since %s"),
+	        format_date('', $date_joined)).
+	        '</font>';
 	    }
 	  $content .= '</li>';
 	  $exists=1;
