@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: quitproject.php,v 1.4 2005/06/30 17:19:36 toddy Exp $
+# $Id: quitproject.php 5187 2005-12-01 16:22:29Z yeupou $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #                          Wallace Lee
@@ -50,7 +50,8 @@ if ($cancel)
 if (!$confirm && !$pending)
 {  
   site_user_header(array('title'=>_("Quit a group"),
-			 'toptab'=>'mygroups'));
+			 'context'=>'mygroups'));
+
   print '<form action="'.$GLOBALS[PHP_SELF].'" method="post">';
   print '<input type="hidden" name="quitting_group_id" value="'.$quitting_group_id.'" />';  
   print '<font class="preinput">'.sprintf(_("You are about to leave the group %s, please confirm:"), group_getname($quitting_group_id)).'</font>';
