@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: index.php,v 1.25 2005/06/30 17:19:36 toddy Exp $
+# $Id: index.php 5187 2005-12-01 16:22:29Z yeupou $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2000-2001 (c) Free Software Foundation
@@ -34,7 +34,8 @@ $category_id = $_REQUEST['category_id'];
 if ($group_id)
 {
 
-  site_project_header(array('title'=>_('Project Help Wanted'),'group'=>$group_id,'toptab'=>'people'));
+  site_project_header(array('title'=>_('Project Help Wanted'),'group'=>$group_id,'context'=>'people'));
+
 
   # we get site-specific content
   utils_get_content("people/index_group");
@@ -50,10 +51,12 @@ $cat_name = people_get_category_name($category_id);
 
 if ($cat_name == 'Invalid ID')
 	{
-		print site_header(array('title' =>_('Project Help Wanted'), 'toptab'=>_('people')));
+		print site_header(array('title' =>_('Project Help Wanted'), 'context'=>_('people')));
+
 		fb(_("Invalid category: that category does not exist"),1);
 	} else {
-		print site_header(array('title'=>sprintf(_('Projects looking for %s'), $cat_name), 'toptab'=>_('people')));
+		print site_header(array('title'=>sprintf(_('Projects looking for %s'), $cat_name), 'context'=>_('people')));
+
 
   # we get site-specific content
   utils_get_content("people/index_cat");
@@ -65,7 +68,8 @@ if ($cat_name == 'Invalid ID')
 else
 {
 
-  print site_header(array('title'=>_('Projects Needing Help'), 'toptab'=>_('people')));
+  print site_header(array('title'=>_('Projects Needing Help'), 'context'=>_('people')));
+
 
   # we get site-specific content
   utils_get_content("people/index");
