@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: editgroupinfo.php,v 1.45 2005/06/30 17:19:36 toddy Exp $
+# $Id: editgroupinfo.php 5187 2005-12-01 16:22:29Z yeupou $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2000-2003 (c) Free Software Foundation
@@ -56,7 +56,8 @@ if (db_numrows($res_grp) < 1)
 $row_grp = db_fetch_array($res_grp);
 
 
-site_project_header(array('title'=>_("Editing Public Infos"),'group'=>$group_id,'toptab'=>'ahome'));
+site_project_header(array('title'=>_("Editing Public Infos"),'group'=>$group_id,'context'=>'ahome'));
+
 
 
 # ####################################### General Description
