@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: history.php,v 1.15 2005/06/30 17:19:36 toddy Exp $
+# $Id: history.php 5187 2005-12-01 16:22:29Z yeupou $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2000-2003 (c) Free Software Foundation
@@ -28,7 +28,8 @@ require ('../../include/pre.php');
 
 if (member_check(0, $group_id))
 {
-  site_project_header(array('title'=>_("Project History"),'group'=>$group_id,'toptab'=>'ahome'));
+  site_project_header(array('title'=>_("Project History"),'group'=>$group_id,'context'=>'ahome'));
+
   
   show_grouphistory($group_id);
 
