@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: userperms.php,v 1.35 2005/09/14 18:33:45 toddy Exp $
+# $Id: userperms.php 5187 2005-12-01 16:22:29Z yeupou $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2000-2003 (c) Free Software Foundation
@@ -66,17 +66,36 @@ if ($update)
       $task_flags="task_user_$row_dev[user_id]";
       $patch_flags="patch_user_$row_dev[user_id]";
       $support_flags="support_user_$row_dev[user_id]";
+      $cookbook_flags="cookbook_user_$row_dev[user_id]";
       $news_flags="news_user_$row_dev[user_id]";
 
       $sql = 'UPDATE user_group SET '
-	 ."admin_flags='".$$admin_flags."',"
-	 ."privacy_flags='".$$privacy_flags."',"
-	 ."bugs_flags=".$$bugs_flags.","
-	 ."news_flags=".$$news_flags.","
-	 ."task_flags=".$$task_flags.", "
-	 ."patch_flags=".$$patch_flags.", "
-	 ."support_flags=".$$support_flags." "
-	 ."WHERE user_id='$row_dev[user_id]' AND group_id='$group_id'";
+	."admin_flags='".safeinput($$admin_flags)."',"
+	."privacy_flags='".safeinput($$privacy_flags)."',"
+	."cookbook_flags=".safeinput($$cookbook_flags).",";
+      
+      if ($project->Uses("bugs")) 
+	{
+	  $sql .= "bugs_flags=".safeinput($$bugs_flags).",";
+	}
+      if ($project->Uses("news")) 
+	{
+	  $sql .= "news_flags=".safeinput($$news_flags).",";
+	}
+      if ($project->Uses("task")) 
+	{
+	  $sql .= "task_flags=".safeinput($$task_flags).",";
+	}
+      if ($project->Uses("patch")) 
+	{
+	  $sql .= "patch_flags=".safeinput($$patch_flags).",";
+	}
+      if ($project->Uses("support")) 
+	{
+	  $sql .= "support_flags=".safeinput($$support_flags).",";
+	}
+      $sql = rtrim($sql, ",");
+      $sql .= " WHERE user_id='$row_dev[user_id]' AND group_id='$group_id'";
 
       $result = db_query($sql);
       $name = user_getname($row_dev['user_id']);
@@ -90,7 +109,6 @@ if ($update)
 	}
       else
 	{
-	  print db_error();
 	  $feedback_unable .= $name.", ";
 	}
     }
@@ -113,6 +131,7 @@ if ($update)
   $task_flags="task_user_";
   $patch_flags="patch_user_";
   $support_flags="support_user_";
+  $cookbook_flags="cookbook_user_";
   $news_flags="news_user_";
 
   # If the group entry do not exists, create it
@@ -123,12 +142,30 @@ if ($update)
 
   # Update the table
   $sql = 'UPDATE groups_default_permissions SET '
-     ."bugs_flags=".$$bugs_flags.","
-     ."news_flags=".$$news_flags.","
-     ."task_flags=".$$task_flags.", "
-     ."patch_flags=".$$patch_flags.", "
-     ."support_flags=".$$support_flags." "
-     ."WHERE group_id='$group_id'";
+    ."cookbook_flags=".safeinput($$cookbook_flags).",";
+  
+  if ($project->Uses("bugs")) 
+    {
+      $sql .= "bugs_flags=".safeinput($$bugs_flags).",";
+    }
+  if ($project->Uses("news")) 
+    {
+      $sql .= "news_flags=".safeinput($$news_flags).",";
+    }
+  if ($project->Uses("task")) 
+    {
+      $sql .= "task_flags=".safeinput($$task_flags).",";
+    }
+  if ($project->Uses("patch")) 
+    {
+      $sql .= "patch_flags=".safeinput($$patch_flags).",";
+    }
+  if ($project->Uses("support")) 
+    {
+      $sql .= "support_flags=".safeinput($$support_flags).",";
+    }
+  $sql = rtrim($sql, ",");
+  $sql .= " WHERE group_id='$group_id'";
 
   $result = db_query($sql);
 
@@ -169,15 +206,22 @@ if ($update)
   if (!$patch_flags)
     { $patch_flags = 'NULL'; }
 
+  $newitem_restrict_event1 = "cookbook_restrict_event1";
+  $newitem_restrict_event2 = "cookbook_restrict_event2";
+  $cookbook_flags = ($$newitem_restrict_event2)*100 + $$newitem_restrict_event1;
+  if (!$cookbook_flags)
+    { $cookbook_flags = 'NULL'; }
+
   $news_flags="news_restrict_event1";
 
   # Update the table
   $sql = 'UPDATE groups_default_permissions SET '
-     ."bugs_rflags=".$bugs_flags.","
-     ."news_rflags=".$$news_flags.","
-     ."task_rflags=".$task_flags.", "
-     ."patch_rflags=".$patch_flags.", "
-     ."support_rflags=".$support_flags." "
+     ."bugs_rflags=".safeinput($bugs_flags).","
+     ."news_rflags=".safeinput($$news_flags).","
+     ."cookbook_rflags=".safeinput($cookbook_flags).","
+     ."task_rflags=".safeinput($task_flags).", "
+     ."patch_rflags=".safeinput($patch_flags).", "
+     ."support_rflags=".safeinput($support_flags)." "
      ."WHERE group_id='$group_id'";
 
   $result = db_query($sql);
@@ -192,14 +236,11 @@ if ($update)
     {
       fb(_("Unable to change posting restrictions."), 1);
     }
-
-
 }
 
 
-
 # start HTML
-site_project_header(array('title'=>_("Permissions Management"),'group'=>$group_id,'toptab'=>'ahome'));
+site_project_header(array('title'=>_("Permissions Management"),'group'=>$group_id,'context'=>'ahome'));
 
 
 $sql = "select user.user_name AS user_name,"
@@ -208,6 +249,7 @@ $sql = "select user.user_name AS user_name,"
 . "user_group.admin_flags, "
 . "user_group.privacy_flags, "
 . "user_group.bugs_flags, "
+. "user_group.cookbook_flags, "
 . "user_group.forum_flags, "
 . "user_group.task_flags, "
 . "user_group.patch_flags, "
@@ -225,47 +267,96 @@ print '<form action="'.$PHP_SELF.'" method="post">
 ########################### POSTING RESTRICTIONS
 # Exists also in trackers config (missing for news).
 
-  $title_arr=array();
-  $title_arr[]=_("Applies when ...");
+$title_arr=array();
+$title_arr[]=_("Applies when ...");
+if ($project->Uses("support")) 
+{
   $title_arr[]=_("Support Tracker");
+}
+if ($project->Uses("bugs")) 
+{
   $title_arr[]=_("Bug Tracker");
+}
+if ($project->Uses("task")) 
+{
   $title_arr[]=_("Task Tracker");
+}
+if ($project->Uses("patch")) 
+{
   $title_arr[]=_("Patch Tracker");
-  $title_arr[]=_("News");
+} 
+$title_arr[]=_("Cookbook Manager");
+if ($project->Uses("news")) 
+{
+  $title_arr[]=_("News Manager");
+}
 
-  print '<h3>'._("Group trackers posting restrictions").'</h3>';
+print '<h3>'._("Group trackers posting restrictions").'</h3>';
 
-  print '<p>';
-  print _("Here you can set the minimal authentification level required in order to post on the trackers.");
-  print '</p>';
+print '<p>';
+print _("Here you can set the minimal authentification level required in order to post on the trackers.");
+print '</p>';
 
-  print html_build_list_table_top ($title_arr);
+print html_build_list_table_top ($title_arr);
 
-  $i++;
-  print '
+$i++;
+print '
   <tr class="'. utils_get_alt_row_color($i) .'">
     <td>'._("Posting new items").'</td>';
+if ($project->Uses("support")) 
+{
   html_select_restriction_box("support", group_getrestrictions($group_id, "support"));
+}
+if ($project->Uses("bugs")) 
+{
   html_select_restriction_box("bugs", group_getrestrictions($group_id, "bugs"));
+}
+if ($project->Uses("task")) 
+{
   html_select_restriction_box("task", group_getrestrictions($group_id, "task"));
+}
+if ($project->Uses("patch")) 
+{
   html_select_restriction_box("patch", group_getrestrictions($group_id, "patch"));
+} 
+html_select_restriction_box("cookbook", group_getrestrictions($group_id, "cookbook"));
+if ($project->Uses("news")) 
+{
   html_select_restriction_box("news", group_getrestrictions($group_id, "news"));
-  print '  </tr>';
+}
 
-  $i++;
-  print '
+print '  </tr>';
+
+$i++;
+print '
   <tr class="'. utils_get_alt_row_color($i) .'">
     <td>'._("Posting comments").'</td>';
+if ($project->Uses("support")) 
+{
   html_select_restriction_box("support", group_getrestrictions($group_id, "support", 2),'', '', 2);
+}
+if ($project->Uses("bugs")) 
+{
   html_select_restriction_box("bugs", group_getrestrictions($group_id, "bugs", 2),'', '', 2);
+}
+if ($project->Uses("task")) 
+{
   html_select_restriction_box("task", group_getrestrictions($group_id, "task", 2),'', '', 2);
+}
+if ($project->Uses("patch")) 
+{
   html_select_restriction_box("patch", group_getrestrictions($group_id, "patch", 2),'', '', 2);
+}
+html_select_restriction_box("cookbook", group_getrestrictions($group_id, "cookbook", 2),'', '', 2);
+if ($project->Uses("news")) 
+{
 # not yet effective!
   print '<td align="center">---</td>';
 #  html_select_restriction_box("news", group_getrestrictions($group_id, "news", 2),'', '', 2);
-  print '  </tr>';
-
-  print '
+}
+print '  </tr>';
+ 
+print '
 </table>
 <p align="center"><input type="submit" name="update" value="'._("Update Permissions").'"></p>';
 
@@ -273,22 +364,53 @@ print '<form action="'.$PHP_SELF.'" method="post">
 ########################### GROUP DEFAULTS
 
 $title_arr=array();
-$title_arr[]=_("Support Tracker");
-$title_arr[]=_("Bug Tracker");
-$title_arr[]=_("Task Tracker");
-$title_arr[]=_("Patch Tracker");
-$title_arr[]=_("News");
+if ($project->Uses("support")) 
+{
+  $title_arr[]=_("Support Tracker");
+}
+if ($project->Uses("bugs")) 
+{
+  $title_arr[]=_("Bug Tracker");
+}
+if ($project->Uses("task")) 
+{
+  $title_arr[]=_("Task Tracker");
+}
+if ($project->Uses("patch")) 
+{
+  $title_arr[]=_("Patch Tracker");
+} 
+$title_arr[]=_("Cookbook Manager");
+if ($project->Uses("news")) 
+{
+  $title_arr[]=_("News Manager");
+}
 
 print '<h3>'._("Group Default Permissions").'</h3>';
 member_explain_roles();
 print html_build_list_table_top ($title_arr);
 
+if ($project->Uses("support")) 
+{
 html_select_permission_box("support", group_getpermissions($group_id, "support"), "group");
+}
+if ($project->Uses("bugs")) 
+{
 html_select_permission_box("bugs", group_getpermissions($group_id, "bugs"), "group");
+}
+if ($project->Uses("task")) 
+{
 html_select_permission_box("task", group_getpermissions($group_id, "task"), "group");
+}
+if ($project->Uses("patch")) 
+{
 html_select_permission_box("patch", group_getpermissions($group_id, "patch"), "group");
+}
+html_select_permission_box("cookbook", group_getpermissions($group_id, "cookbook"), "group");
+if ($project->Uses("news")) 
+{
 html_select_permission_box("news", group_getpermissions($group_id, "news"), "group");
-
+}
 
 print '  </tr>
 </table>
@@ -303,20 +425,32 @@ if (!$result || db_numrows($result) < 1)
 }
 else
 {
-  # If we have more than 15 users, do not print list with selectboxes,
-  # it does not scale, the page would be too big.
-
   print '<p>&nbsp;</p>';
 
   $title_arr=array();
   $title_arr[]=_("Member");
   $title_arr[]=_("General Rights");
-  $title_arr[]=_("Support Tracker");
-  $title_arr[]=_("Bug Tracker");
-  $title_arr[]=_("Task Tracker");
-  $title_arr[]=_("Patch Tracker");
-  $title_arr[]=_("News");
-
+  if ($project->Uses("support")) 
+    {
+      $title_arr[]=_("Support Tracker");
+    }
+  if ($project->Uses("bugs")) 
+    {
+      $title_arr[]=_("Bug Tracker");
+    }
+  if ($project->Uses("task")) 
+    {
+      $title_arr[]=_("Task Tracker");
+    }
+  if ($project->Uses("patch")) 
+    {
+      $title_arr[]=_("Patch Tracker");
+    } 
+  $title_arr[]=_("Cookbook Manager");
+  if ($project->Uses("news")) 
+    {
+      $title_arr[]=_("News Manager");
+    }
 
   print '<h3>'._("Permissions per member").'</h3>';
   print '<p class="warn">';
@@ -362,12 +496,27 @@ else
      print '
     </td>';
 
-
-     html_select_permission_box("support", $row);
-     html_select_permission_box("bugs", $row);
-     html_select_permission_box("task", $row);
-     html_select_permission_box("patch", $row);
-     html_select_permission_box("news", $row);
+     if ($project->Uses("support")) 
+       {
+	 html_select_permission_box("support", $row);
+       }
+     if ($project->Uses("bugs")) 
+       {
+	 html_select_permission_box("bugs", $row);
+       }
+     if ($project->Uses("task")) 
+       {
+	 html_select_permission_box("task", $row);
+       }
+     if ($project->Uses("patch")) 
+       {
+	 html_select_permission_box("patch", $row);
+       }
+     html_select_permission_box("cookbook", $row);
+     if ($project->Uses("news")) 
+       {
+	 html_select_permission_box("news", $row);
+       }
 
      print '  </tr>';
 
@@ -380,6 +529,6 @@ else
 
 }
 
-
 project_admin_footer(array());
-?>
+
+?>
\ No newline at end of file
