@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: memberlist-gpgkeys.php,v 1.5 2005/09/14 15:51:30 toddy Exp $
+# $Id: memberlist-gpgkeys.php 5187 2005-12-01 16:22:29Z yeupou $
 #
 #  Copyright 2005      (c) Mathieu Roy <yeupou--at--gnu.org>
 #
@@ -31,7 +31,8 @@ if (!$keyring) {
 if (!$download) {
   site_project_header(array('title'=>_("Project Members GPG Keyring"),
 			    'group'=>$group_id,
-			    'toptab'=>'keys'));
+			    'context'=>'keys'));
+
 
   print '<p>'._("Below is the content of this project's keyring. These are the successfully registered keys of project members.").'</p>';
   print nl2br(htmlspecialchars($keyring));
