@@ -2,15 +2,15 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: memberlist.php,v 1.33 2005/09/23 14:42:56 toddy Exp $
+# $Id: memberlist.php 5187 2005-12-01 16:22:29Z yeupou $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2000-2003 (c) Free Software Foundation
 #                          Mathieu Roy <yeupou--at--gnu.org>
 #
-#  Copyright 2004      (c) Mathieu Roy <yeupou--at--gnu.org>
+#  Copyright 2004-2005 (c) Mathieu Roy <yeupou--gnu.org>
 #                          Lorenzo Hernandez Garcia-Hierro
-#                                      <lorenzohgh--at--tuxedo-es.org >
+#                                      <lorenzohgh--tuxedo-es.org >
 #
 # The Savane project is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -29,40 +29,28 @@
 require "../include/pre.php";
 require_directory("trackers");
 
-# lorenzo lorenzohgh@tuxedo-es.org
-# Declaring variables BY method
-if ($_POST['group_id'])
-   { $group_id = $_POST['group_id']; }
-elseif ($_GET['group_id'])
-  { $group_id = $_GET['group_id'];  }
-if ($_GET['group'])
-  { $group = $_GET['group']; }
-if ($_GET['detailed'])
-  { $detailed = $_GET['detailed']; }
-if ($_GET['words'])
-  { $words = $_GET['words']; }
+$detailed = sane_get("detailed");
+$form_tgrp = sane_all("form_grp");
 
 if ((!$group_id) && $form_grp)
-     $group_id=$form_grp;
-
+{
+  $group_id=$form_grp;
+}
+     
      site_project_header(array('title'=>_("Project Memberlist"),
 			       'group'=>$group_id,
-			       'toptab'=>'people'));
+			       'context'=>'people'));
 
-
-     /* permit to the user to specify something */
-
-     print '<form action="'. $PHP_SELF .'" method="get">';
-     print '<input type="hidden" name="group" value="'.$group_name.'">';
-     print '<h3>';
+     
      if ($detailed)
-{ $checked = " selected"; }
+{ $checked = " selected=\"selected\""; }
 # I18N
 # %s currently is "basic" or "detailed"
-printf (_("Browse with the %s memberlist."), '<select name="detailed"><option value="0">'._("basic").'</option><option value="1"'.$checked.'>'._("detailed").'</option></select>');
-print '&nbsp;&nbsp;&nbsp;&nbsp;<input type="submit" value="'._("Apply").'"></h3></form>';
-
-print '<br />';
+  $form_opening = '<form action="'.$PHP_SELF.'#options" method="get">';
+  $form_submit = '<input class="bold"  type="submit" value="'._("Apply").'" />';
+print html_show_displayoptions(sprintf(_("Browse with the %s memberlist."), '<select name="detailed"><option value="0">'._("basic").'</option><option value="1"'.$checked.'>'._("detailed").'</option></select>').'<input type="hidden" name="group" value="'.$group_name.'">',
+			       $form_opening,
+			       $form_submit);
 
 
 if (!member_check(0,$group_id))
@@ -123,6 +111,7 @@ else
 
 
 $title_arr=array();
+$title_arr[]="&nbsp;";
 $title_arr[]=_("Member");
 if ($detailed)
 { $title_arr[]=_("Specific Role"); }
@@ -177,13 +166,13 @@ while ($row_memb=db_fetch_array($res_memb))
 	      $icon_alt = _("Site Administrator");
 	    }
 
-	  print "\t\t".'<td><img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/'.$icon.'.png" alt="'.$icon_alt.'" class="icon" /> '.utils_user_link($row_memb[user_name], $row_memb[realname])."</td>\n";
+	  print "\t\t".'<td class="center"><font class="help" title="'.$icon_alt.'"><img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/'.$icon.'.png" alt="'.$icon_alt.'" class="icon" /></font></td><td>'.utils_user_link($row_memb[user_name], $row_memb[realname])."</td>\n";
 	}
       else
 	{
 	  $icon = "project-member";
 	  $icon_alt = _("Project Member");
-	  print "\t\t".'<td><img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/'.$icon.'.png" alt="'.$icon_alt.'" class="icon" /> '.utils_user_link($row_memb[user_name], $row_memb[realname])."</td>\n";
+	  print "\t\t".'<td><font class="help" title="'.$icon_alt.'"><img src="'.$GLOBALS['sys_home'].'images/'.SV_THEME.'.theme/'.$icon.'.png" alt="'.$icon_alt.'" class="icon" /></font></td><td>'.utils_user_link($row_memb[user_name], $row_memb[realname])."</td>\n";
 	}
 
       # Role
