@@ -2,7 +2,7 @@
 # This file is part of the Savane project
 # <http://gna.org/projects/savane/>
 #
-# $Id: projectname.php,v 1.36 2005/06/30 17:19:37 toddy Exp $
+# $Id: projectname.php 5187 2005-12-01 16:22:29Z yeupou $
 #
 #  Copyright 1999-2000 (c) The SourceForge Crew
 #  Copyright 2000-2003 (c) Free Software Foundation
@@ -113,7 +113,7 @@ print '<input type="hidden" name="rand_hash" value="'.(isset($rand_hash) ? $rand
 if (!group_getid($GLOBALS['sys_unix_group_name']))
 {
   print '<h3>'._("Full Name").' :</h3>';
-  print '<input size="60" maxlength="254" type="text" name="form_full_name" value="Local Administration">';
+  print '<input size="60" maxlength="254" type="text" name="form_full_name" value="Site Administration">';
 
   print '<h3>'._("System Name").' :</h3>';
   print '<input type="hidden" name="form_unix_name" value="'.$GLOBALS['sys_unix_group_name'].'"><b>'.$GLOBALS['sys_unix_group_name'].'</b>';
