@@ -5,18 +5,18 @@ print "	<title>Basic PHP tests</title>\n";
 print "</head>\n";
 print "<body>\n";
 
+
 print "<h1>Basic PHP pre-tests for Savane installation</h1>\n";
 print "<p>This page should help you to check whether your installation is properly configured. Once your installation is running, you should however probably removed it, or restrict its access, since it could give up to anybody details bout your setup.</p>";
 
-#=================================================================================
-print "<h2>PHP configuration:</h2>\n";
+#==============================================================================
+print "<h2>Base PHP configuration:</h2>\n";
 
 $phptags = array (
 	'register_globals' => 1,
+	'register_long_arrays' => 1,
 	'file_uploads' => 1,
 	'magic_quotes_gpc' => 1,
-	'display_errors' => 1,
-	'register_long_array' => 1,
 	'post_max_size' => '2M',
 	'upload_max_filesize' => '2M',
 	'arg_separator.output' => '&amp;',
@@ -25,6 +25,7 @@ $phptags = array (
 print "<table border=\"1\">\n";
 print "<tr><th>PHP Tag name</th><th>Local value</th><th>Suggested/Required value</th></tr>\n";
 unset($unset);
+ksort($phptags);
 foreach ( $phptags as $tag => $goodval ) {
   if (htmlentities(ini_get($tag)) == htmlentities($goodval)) 
     {
@@ -38,18 +39,18 @@ foreach ( $phptags as $tag => $goodval ) {
     }
   else
     {
-      # Non existing ini value.
-      printf ("<tr><td>%s</td><td>Unset *</td><td>%s</td></tr>\n",$tag,htmlentities($goodval));
+      # Non existing ini value: may be unset or Off 
+      printf ("<tr><td>%s</td><td bgcolor=\"#ffdada\"><font color=\"black\">Off or Unset *</font></td><td>%s</td></tr>\n",$tag,htmlentities($goodval));
       $unset = 1;
     }
 }
 print "</table>\n";
 if ($unset)
 {
-  print "<p>* Unset means that this tag does was not found at all and is probably irrelevant to your PHP installation. You should ignore this entry.</p>";
+  print "<blockquote>* This tag was set to Off or not found at all. Look for this tag in php.ini. If you find it, update it accordingly. Otherwise, if you cannot find such tag in your php.ini file, it is probably irrelevant to your PHP installation and then should ignore this entry.</blockquote>";
 }
 
-#=================================================================================
+#==============================================================================
 print "<h2>PHP functions:</h2>\n";
 
 $phpfunctions = array (
@@ -66,7 +67,7 @@ foreach ( $phpfunctions as $func => $comment ) {
 	}
 }
 
-#=================================================================================
+#==============================================================================
 print "<h2>Apache environnement vars:</h2>\n";
 
 $configfile = '/etc/savannah/';
@@ -89,7 +90,7 @@ if (is_readable($configfile)) {
    print "File <b>$configfile</b> does not exist or is not readable!";
 }
 
-#=================================================================================
+#==============================================================================
 print "<h2>Savane configuration:</h2>\n";
 
 if (!is_readable($configfile)) 
@@ -142,6 +143,48 @@ else
 }
 
 
+#=============================================================================
+print "<h2>Securing PHP configuration:</h2>\n";
+
+print "The following is not required to run Savane but could enhance security of your production server. Some of these makes harder to debug an installation and, as such, should be avoided on a test installation, or if your installation is not working.";
+
+$phptags = array (
+	'display_errors' => 'Off',
+	'allow_url_fopen' => 'Off',
+	'disable_functions' => 'exec, passthru, popen, shell_exec, system',
+);
+
+print "<table border=\"1\">\n";
+print "<tr><th>PHP Tag name</th><th>Local value</th><th>Suggested/Required value</th></tr>\n";
+unset($unset);
+ksort($phptags);
+foreach ( $phptags as $tag => $goodval ) {
+  if (htmlentities(ini_get($tag)) == htmlentities($goodval)) 
+    {
+      # OK
+      printf ("<tr><td>%s</td><td>%s</td><td>%s</td></tr>\n",$tag,htmlentities(ini_get($tag)),htmlentities($goodval));
+    }
+  else if (htmlentities(ini_get($tag)))
+    {
+      # Different  
+      printf ("<tr><td>%s</td><td bgcolor=\"#ffadad\"><font color=\"black\">%s</font></td><td>%s</td></tr>\n",$tag,htmlentities(ini_get($tag)),htmlentities($goodval));
+    }
+  else
+    {
+      # Non existing ini value: may be unset or Off 
+      printf ("<tr><td>%s</td><td bgcolor=\"#ffdada\"><font color=\"black\">Off or Unset *</font></td><td>%s</td></tr>\n",$tag,htmlentities($goodval));
+      $unset = 1;
+    }
+}
+print "</table>\n";
+if ($unset)
+{
+  print "<blockquote>* This tag was set to Off or not found at all. Look for this tag in php.ini. If you find it, update it accordingly. Otherwise, if you cannot find such tag in your php.ini file, it is probably irrelevant to your PHP installation and then should ignore this entry.</blockquote>";
+}
+
+
+#==============================================================================
+
 print "<h2>That's it!</h2>";
 print "</body>\n<html>\n";
 
